#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wired_network_devices_id_config_features_intended_layer2_feature
short_description: Resource module for Wired Network Devices Id Config Features Intended Layer2 Feature
description:
  - Manage operations create, update and delete of the resource Wired Network Devices Id Config Features Intended Layer2 Feature.
    - > This API creates configurations for an intended feature on a wired device. Once all the updates to intended features
    are complete, they can be deployed to a device using the API /dna/intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy.
    When the intended features are deployed, they are applied on top of the existing configurations on the device. Any existing
    configurations on the device which are not included in the intended features, are retained on the device. - > This API
    deletes the configurations for an intended feature on a wired device. Once all the updates to intended features are complete,
    they can be deployed to a device using the API /dna/intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy.
    When the intended features are deployed, they are applied on top of the existing configurations on the device. Any existing
    configurations on the device which are not included in the intended features, are retained on the device. - > This API
    updates the configurations for an intended feature on a wired device. Updates to other intended features can be done over
    several iterations. Once all the updates to intended features are complete, they can be deployed to a device using the
    API /dna/intent/api/v1/networkDevices/{id}/configFeatures/intended/deploy. When the intended features are deployed, they
    are applied on top of the existing configurations on the device. Any existing configurations on the device which are not
    included in the intended features, are retained on the device.
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  cdpGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's cdpGlobalConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality configured for CDP. Config type CDP_GLOBAL is for configuring the global
              settings for CDP.
            type: str
          holdTime:
            description: Specifies the amount of time a receiving device should hold the information sent by the device before
              discarding it. Corresponding CLI - cdp holdtime <10-255>.
            type: int
          isAdvertiseV2Enabled:
            description: Configures CDP to send Version-2 advertisements. The default state is enabled. Corresponding CLI
              - cdp advertise-v2.
            type: bool
          isCdpEnabled:
            description: Enables or disables CDP on the device. Corresponding CLI - cdp run. Default true.
            type: bool
          isLogDuplexMismatchEnabled:
            description: Configures the reporting of duplex mismatches generated by CDP for all Ethernet interfaces on the
              device. Corresponding CLI - cdp log mismatch. Duplex. Default true.
            type: bool
          timer:
            description: Sets the transmission frequency of CDP updates in seconds. Corresponding CLI - cdp timer <5-254>.
            type: int
        type: list
    type: dict
  cdpInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's cdpInterfaceConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type CDP_INTERFACE is for configuring CDP on
              an interface.
            type: str
          interfaceName:
            description: Interface name. The API /dna/intent/api/v1/interface/network-device/{deviceId} can be used to get
              the list of interfaces on a device. Example GigabitEthernet1/0/1.
            type: str
          isCdpEnabled:
            description: Enables or disables CDP on the interface. Corresponding CLI - cdp enable. Default true.
            type: bool
          isLogDuplexMismatchEnabled:
            description: Configures the reporting of duplex mismatches generated by CDP for all Ethernet interfaces on the
              device. Corresponding CLI - cdp log mismatch duplex. Default true.
            type: bool
        type: list
    type: dict
  dhcpSnoopingGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's dhcpSnoopingGlobalConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type DHCP_SNOOPING_GLOBAL is for configuring
              the global settings for DHCP snooping.
            type: str
          databaseAgent:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's databaseAgent.
            suboptions:
              agentUrl:
                description: Example tftp //192.168.1.100/db_backup Specify the URL for the database agent or the binding
                  file. Corresponding CLI - ip dhcp snooping database .
                type: str
              configType:
                description: Type of network functionality under a feature. Config type DHCP_SNOOPING_DATABASE_AGENT is for
                  configuring DHCP snooping database agent settings on a device.
                type: str
              timeout:
                description: Specify the duration, in seconds, after which a configuration process will be automatically terminated.
                  Corresponding CLI - ip dhcp snooping database timeout <0-86400>.
                type: int
              writeDelay:
                description: WriteDelay.
                type: int
            type: dict
          dhcpSnoopingVlans:
            description: Enable DHCP snooping on VLANs. VLANs can be comma separated and/or a range like '2,4-5,7,10-20'.
              Corresponding CLI - ip dhcp snooping vlan .
            type: str
          isDhcpSnoopingEnabled:
            description: Enable DHCP snooping globally. Corresponding CLI - ip dhcp snooping.default false.
            type: bool
          isGleaningEnabled:
            description: Enable DHCP gleaning which allows components to register and glean only DHCP version 4 packets. Corresponding
              CLI - ip dhcp snooping glean.default false.
            type: bool
          proxyBridgeVlans:
            description: Enable bridge mode on VLANs. VLANs can be comma separated and/or a range like '2,4-5,7,10-20'. Corresponding
              CLI - ip dhcp snooping vlan proxy-bridge.
            type: str
        type: list
    type: dict
  dhcpSnoopingInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's dhcpSnoopingInterfaceConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type DHCP_SNOOPING_INTERFACE is for configuring
              DHCP snooping on an interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the
              list of interfaces on a device.example GigabitEthernet1/0/1.
            type: str
          isTrustedInterface:
            description: Enable Trusted Interface. Corresponding CLI - ip dhcp snooping trust.
            type: bool
          messageRateLimit:
            description: Limit the number of DHCP packets a port can send or receive in a second. This is a protective measure
              to prevent a single device from overwhelming the DHCP server. Increase the rate limit on trunk ports carrying
              more than one VLAN. By default, rate limit is disabled. The recommended value is <= 100. Set the rate-limit
              as 0 to disable it. Corresponding CLI - ip dhcp snooping limit rate <1-2048>.
            type: int
        type: list
    type: dict
  dot1xGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's dot1xGlobalConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          authenticationConfigMode:
            description: ReadOnly attribute. Identity-Based Networking Services features are configured in the Cisco common
              classification policy language (C3PL) display mode. The legacy authentication manager mode is enabled by default.
              Use this command in EXEC mode to display the current configuration mode. Corresponding CLI - authentication
              display config-mode. LEGACY - Legacy configuration mode. NEW_STYLE - Identity-Based Networking Services (IBNS)
              configuration mode.
            type: str
          configType:
            description: Type of network functionality under a feature. Config type DOT1X_GLOBAL is for global 802.1x settings
              on a device.
            type: str
          isDot1xEnabled:
            description: Globally enable 802.1x authentication on Switch. Corresponding CLI - dot1x system-auth-control. Default
              false.
            type: bool
        type: list
    type: dict
  dot1xInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's dot1xInterfaceConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          authenticationOrder:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's authenticationOrder.
            suboptions:
              configType:
                description: ConfigType.
                type: str
              items:
                description: Array of Enums. DOT1X, MAB, WEBAUTH.
                elements: str
                type: list
            type: dict
          configType:
            description: Type of network functionality under a feature. Config type DOT1X_INTERFACE is for configuring 802.1x
              on an interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the
              list of interfaces on a device.example GigabitEthernet1/0/1.
            type: str
        type: list
    type: dict
  feature:
    description: Feature path parameter. Name of the feature to delete.
    type: str
  id:
    description: Id path parameter. Network device ID of the wired device to configure.
    type: str
  igmpSnoopingGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's igmpSnoopingGlobalConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type IGMP_SNOOPING_GLOBAL is for configuring
              global IGMP snooping settings on a device.
            type: str
          igmpSnoopingVlanSettings:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's igmpSnoopingVlanSettings.
            suboptions:
              configType:
                description: ConfigType.
                type: str
              items:
                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                elements: dict
                suboptions:
                  configType:
                    description: Type of network functionality under a feature. Config type IGMP_SNOOPING_VLAN is for configuring
                      IGMP snooping per VLAN.
                    type: str
                  igmpSnoopingVlanMrouters:
                    description: Wired Network Devices Id Config Features Intended Layer2 Feature's igmpSnoopingVlanMrouters.
                    suboptions:
                      configType:
                        description: Type of IGMP Snooping Mrouter Settings.
                        type: str
                      items:
                        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                        elements: dict
                        suboptions:
                          configType:
                            description: Type of network functionality under a feature. Config type IGMP_SNOOPING_VLAN_MROUTER
                              is for configuring IGMP snooping mrouter per VLAN.
                            type: str
                          interfaceName:
                            description: Mrouter interface name. The API /dna/intent/api/v1/interface/network-devic... can
                              be used to get the list of interfaces on a device.example GigabitEthernet1/0/2.
                            type: str
                        type: list
                    type: dict
                  isIgmpSnoopingEnabled:
                    description: Enable IGMP Snooping for a VLAN. Corresponding CLI - ip igmp snooping vlan <1-4094>.
                    type: bool
                  isImmediateLeaveEnabled:
                    description: Enable immediate leave processing for IGMPv2. Corresponding CLI - ip igmp snooping vlan <vlan-id>
                      immediate-leave.default false.
                    type: bool
                  isQuerierEnabled:
                    description: Enable IGMP querier for this VLAN. Corresponding CLI - ip igmp snooping vlan <vlan-id> querier.
                    type: bool
                  querierAddress:
                    description: IGMP querier source IP address. Corresponding CLI - ip igmp snooping vlan <vlan-id> querier
                      address <ip-address>.
                    type: str
                  querierQueryInterval:
                    description: Set the IGMP querier query interval (in seconds). Corresponding CLI - ip igmp snooping vlan
                      <vlan-id> querier query-interval <1-18000>.
                    type: int
                  querierVersion:
                    description: The switch supports IGMP version 1, IGMP version 2, and IGMP version 3. These versions are
                      interoperable on the switch. For example, if IGMP snooping is enabled and the querier's version is IGMPv2,
                      and the switch receives an IGMPv3 report from a host, then the switch can forward the IGMPv3 report
                      to the multicast router. Corresponding CLI - ip igmp snooping querier version <1-3>. IGMP version 1
                      provides the basic query-response mechanism that allows the multicast device to determine which multicast
                      groups are active and other processes that enable hosts to join and leave a multicast group. IGMP version
                      2 extends IGMP functionality by providing such features as the IGMP leave process to reduce leave latency,
                      group-specific queries, and an explicit maximum query response time. IGMPv2 also addsthe capability
                      for routers to elect the IGMP querier without depending on the multicast protocol to perform this task.
                      An IGMP version 3 switch supports Basic IGMPv3SnoopingSupport (BISS), which includes support for the
                      snooping features on IGMPv1 and IGMPv2 switches and for IGMPv3 membership report messages. BISS constrains
                      the flooding of multicast traffic when your network includes IGMPv3 hosts. It constrains traffic to
                      approximately the same set of ports as the IGMP snooping feature on IGMPv2 or IGMPv1 hosts. An IGMPv3
                      switch can receive messages from and forward messages to a device running theSourceSpecific Multicast
                      (SSM) feature.
                    type: str
                  vlanId:
                    description: VLAN ID.
                    type: int
                type: list
            type: dict
          isIgmpSnoopingEnabled:
            description: Enable global IGMP Snooping. Corresponding CLI - ip igmp snooping.default true.
            type: bool
          isQuerierEnabled:
            description: Enable IGMP Snooping Querier. Corresponding CLI - ip igmp snooping querier.default false.
            type: bool
          querierAddress:
            description: Configure IGMP querier source IP address. Corresponding CLI - ip igmp snooping querier address <ip-address>.
            type: str
          querierQueryInterval:
            description: Set the IGMP querier query interval (in seconds). Corresponding CLI - ip igmp snooping querier query-interval
              <1-18000>.
            type: int
          querierVersion:
            description: The switch supports IGMP version 1, IGMP version 2, and IGMP version 3. These versions are interoperable
              on the switch. For example, if IGMP snooping is enabled and the querier's version is IGMPv2, and the switch
              receives an IGMPv3 report from a host, then the switch can forward the IGMPv3 report to the multicast router.
              Corresponding CLI - ip igmp snooping querier version <1-3>. IGMP version 1 provides the basic query-response
              mechanism that allows the multicast device to determine which multicast groups are active and other processes
              that enable hosts to join and leave a multicast group. IGMP version 2 extends IGMP functionality by providing
              such features as the IGMP leave process to reduce leave latency, group-specific queries, and an explicit maximum
              query response time. IGMPv2 also adds the capability for routers to elect the IGMP querier without depending
              on the multicast protocol to perform this task. An IGMP version 3 switch supports Basic IGMPv3SnoopingSupport
              (BISS), which includes support for the snooping features on IGMPv1 and IGMPv2 switches and for IGMPv3 membership
              report messages. BISS constrains the flooding of multicast traffic when your network includes IGMPv3 hosts.
              It constrains traffic to approximately the same set of ports as the IGMP snooping feature on IGMPv2 or IGMPv1
              hosts. An IGMPv3 switch can receive messages from and forward messages to a device running theSourceSpecific
              Multicast (SSM) feature.
            type: str
        type: list
    type: dict
  lldpGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's lldpGlobalConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality configured for LLDP. Config type LLDP_GLOBAL is for configuring the
              global settings for LLDP.
            type: str
          holdTime:
            description: Specifies the amount of time a receiving device should hold the information sent by the device before
              discarding it. Corresponding CLI - lldp holdtime $holdTime <0-32767>.
            type: int
          isLldpEnabled:
            description: Enables or disables LLDP on the device. Corresponding CLI - lldp run. Default true.
            type: bool
          reinitializationDelay:
            description: Specifies the delay time in seconds for LLDP to initialize on any interface. Corresponding CLI -
              lldp reinit <2-5>.
            type: int
          timer:
            description: Sets the transmission frequency of LLDP updates in seconds. Corresponding CLI - lldp timer <5-32767>.
            type: int
        type: list
    type: dict
  lldpInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's lldpInterfaceConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          adminStatus:
            description: Configure the interface to transmit and receive LLDP packets, or disable LLDP on the interface. TRANSMIT_ONLY
              - Configure the interface to transmit LLDP packets only. Corresponding CLI - lldp transmit. RECEIVE_ONLY - Configure
              the interface to receive LLDP packets only. Corresponding CLI - lldp receive. TRANSMIT_AND_RECEIVE - Configure
              the interface to both transmit and receive LLDP packets. Corresponding CLI - lldp receive; lldp transmit. DISABLED
              - Disable LLDP functionality on the device, preventing both transmission and reception of LLDP packets.
            type: str
          configType:
            description: Type of network functionality under a feature. Config type LLDP_INTERFACE is for configuring LLDP
              on an interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the
              list of interfaces on a device. Example GigabitEthernet1/0/1.
            type: str
        type: list
    type: dict
  mabInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's mabInterfaceConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type MAB_INTERFACE is for configuring MAB on
              an interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the
              list of interfaces on a device.
            type: str
          isMabEnabled:
            description: Enable MAC-based authentication on a port. Corresponding CLI - mab. Default false.
            type: bool
        type: list
    type: dict
  mldSnoopingGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's mldSnoopingGlobalConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type MLD_SNOOPING_GLOBAL is for configuring
              MLD snooping settings on a device.
            type: str
          isMldSnoopingEnabled:
            description: Enable global MLD Snooping. Corresponding CLI - ipv6 mld snooping.default false.
            type: bool
          isQuerierEnabled:
            description: Enable MLD Snooping Querier. Corresponding CLI - ipv6 mld snooping querier.default false.
            type: bool
          isSuppressListenerMessagesEnabled:
            description: When Listener Message Suppression is enabled, the switch forwards only a single MLD report per multicast
              router query. Corresponding CLI - ipv6 mld snooping listener-message-suppression.default true.
            type: bool
          mldSnoopingVlanSettings:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's mldSnoopingVlanSettings.
            suboptions:
              configType:
                description: Type of MLD Snooping VLAN Settings.
                type: str
              items:
                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                elements: dict
                suboptions:
                  configType:
                    description: Type of network functionality under a feature. Config type MLD_SNOOPING_VLAN is for configuring
                      MLD snooping per VLAN.
                    type: str
                  isImmediateLeaveEnabled:
                    description: Enable immediate leave processing for MLDv1. Corresponding CLI - ipv6 mld snooping vlan <vlan-id>
                      immediate-leave.default false.
                    type: bool
                  isMldSnoopingEnabled:
                    description: Enable MLD Snooping for a VLAN. Corresponding CLI - ipv6 mld snooping vlan <1-4094>.
                    type: bool
                  isQuerierEnabled:
                    description: Enable MLD querier for this VLAN. Corresponding CLI - ipv6 mld snooping vlan <vlan-id> querier.
                    type: bool
                  mldSnoopingVlanMrouters:
                    description: Wired Network Devices Id Config Features Intended Layer2 Feature's mldSnoopingVlanMrouters.
                    suboptions:
                      configType:
                        description: Type of MLD Snooping Mrouter Settings.
                        type: str
                      items:
                        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                        elements: dict
                        suboptions:
                          configType:
                            description: Type of network functionality under a feature. Config type MLD_SNOOPING_VLAN_MROUTER
                              is for configuring MLD snooping mrouter per VLAN.
                            type: str
                          interfaceName:
                            description: Mrouter interface name. The API /dna/intent/api/v1/interface/network-devic... can
                              be used to get the list of interfaces on a device.example GigabitEthernet1/0/2.
                            type: str
                        type: list
                    type: dict
                  querierAddress:
                    description: MLD querier source IP address. Corresponding CLI - ipv6 mld snooping vlan <vlan-id> querier
                      address <source-ipv6-address>.
                    type: str
                  querierQueryInterval:
                    description: Set the MLD querier query interval (in seconds). Corresponding CLI - ipv6 mld snooping vlan
                      <vlan-id> querier query-interval <1-18000>.
                    type: int
                  querierVersion:
                    description: Configure MLD version. Corresponding CLI - ipv6 mld snooping vlan <vlan-id> querier version
                      <1-2> VERSION_1 - MLDv1 snooping detects MLDv1 control packets and sets up traffic bridging based on
                      IPv6 destination multicast addresses. MLDv1 supports three types of messages - Listener Queries, Multicast
                      Listener Reports, Multicast Listener Done. VERSION_2 - MLDv2 basic snooping (MBSS) uses MLDv2 control
                      packets to set up traffic forwarding based on IPv6 destination multicast addresses. MLDv2 supports MLDv2
                      queries and reports, as well as MLDv1 Report and Done messages.
                    type: str
                  vlanId:
                    description: VLAN ID.
                    type: int
                type: list
            type: dict
          querierAddress:
            description: MLD querier source IP address. Corresponding CLI - ipv6 mld snooping querier address <source-ipv6-address>.
            type: str
          querierQueryInterval:
            description: Set the MLD querier query interval (in seconds). Corresponding CLI - ipv6 mld snooping querier query-interval
              <1-18000>.
            type: int
          querierVersion:
            description: Configure the MLD version. Corresponding CLI - ipv6 mld snooping querier version <1-2> VERSION_1
              - MLDv1 snooping detects MLDv1 control packets and sets up traffic bridging based on IPv6 destination multicast
              addresses. MLDv1 supports three types of messages - Listener Queries, Multicast Listener Reports, Multicast
              Listener Done. VERSION_2 - MLDv2 basic snooping (MBSS) uses MLDv2 control packets to set up traffic forwarding
              based on IPv6 destination multicast addresses. MLDv2 supports MLDv2 queries and reports, as well as MLDv1 Report
              and Done messages.
            type: str
        type: list
    type: dict
  portChannelConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's portChannelConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality configured for Portchannel.
            type: str
          isAutoEnabled:
            description: Enables the auto-LAG feature on a switch globally. Corresponding CLI - port-channel auto.default
              false.
            type: bool
          lacpSystemPriority:
            description: Configures the LACP system priority. Corresponding CLI - lacp system-priority <0-65535>.
            type: int
          loadBalancingMethod:
            description: Configures an EtherChannel load-balancing method. Corresponding CLI - port-channel load-balance .
            type: str
          portchannels:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's portchannels.
            suboptions:
              configType:
                description: Type of Portchannels.
                type: str
              items:
                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                elements: dict
                suboptions:
                  AnyOf:
                    description: Wired Network Devices Id Config Features Intended Layer2 Feature's AnyOf.
                    suboptions:
                      EtherchannelConfig:
                        description: Wired Network Devices Id Config Features Intended Layer2 Feature's EtherchannelConfig.
                        suboptions:
                          configType:
                            description: Type of a Portchannel.
                            type: str
                          memberPorts:
                            description: Wired Network Devices Id Config Features Intended Layer2 Feature's memberPorts.
                            suboptions:
                              configType:
                                description: Type of member ports.
                                type: str
                              items:
                                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                                elements: dict
                                suboptions:
                                  configType:
                                    description: Type of network functionality configured for Etherchannel member port.default
                                      ETHERCHANNEL_MEMBER_PORT_CONFIG.
                                    type: str
                                  interfaceName:
                                    description: InterfaceName.
                                    type: str
                                  mode:
                                    description: Mode.
                                    type: str
                                type: list
                            type: dict
                          minLinks:
                            description: Specifies the minimum number of member ports that must be in the link-up state and
                              bundled in the EtherChannel for the port channel interface to transition to the link-up state.
                              Corresponding CLI - port-channel min-links <2-8>.
                            type: int
                          name:
                            description: Configures the channel group. Corresponding CLI - interface port-channel <1-128>.
                            type: str
                        type: dict
                      LacpPortchannelConfig:
                        description: Wired Network Devices Id Config Features Intended Layer2 Feature's LacpPortchannelConfig.
                        suboptions:
                          configType:
                            description: Type of a Portchannel.
                            type: str
                          memberPorts:
                            description: Wired Network Devices Id Config Features Intended Layer2 Feature's memberPorts.
                            suboptions:
                              configType:
                                description: Type of member ports.
                                type: str
                              items:
                                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                                elements: dict
                                suboptions:
                                  configType:
                                    description: Type of network functionality configured for LACP Portchannel member port.
                                    type: str
                                  interfaceName:
                                    description: Interface name. The API /dna/intent/api/v1/interface/network-devic... can
                                      be used to get the list of interfaces on a device.
                                    type: str
                                  mode:
                                    description: Specify whether a port can send LACP packets or only receive LACP packets.
                                    type: str
                                  portPriority:
                                    description: Configures the LACP port priority. Corresponding CLI - lacp port-priority
                                      <0-65535>.
                                    type: int
                                  rate:
                                    description: Configures the rate at which LACP control packets are received by an LACP-supported
                                      interface. Corresponding CLI - lacp rate fast| normal.
                                    type: int
                                type: list
                            type: dict
                          minLinks:
                            description: Specifies the minimum number of member ports that must be in the link-up state and
                              bundled in the EtherChannel for the port channel interface to transition to the link-up state.
                              Corresponding CLI - port-channel min-links <2-8>.
                            type: int
                          name:
                            description: Configures the channel group. Corresponding CLI - interface port-channel <1-128>.
                            type: str
                        type: dict
                      PagpPortchannelConfig:
                        description: Wired Network Devices Id Config Features Intended Layer2 Feature's PagpPortchannelConfig.
                        suboptions:
                          configType:
                            description: Type of a Portchannel.
                            type: str
                          memberPorts:
                            description: Wired Network Devices Id Config Features Intended Layer2 Feature's memberPorts.
                            suboptions:
                              configType:
                                description: Type of member ports.
                                type: str
                              items:
                                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                                elements: dict
                                suboptions:
                                  configType:
                                    description: Type of network functionality configured for Etherchannel member port.
                                    type: str
                                  interfaceName:
                                    description: Interface name. The API /dna/intent/api/v1/interface/network-devic... can
                                      be used to get the list of interfaces on a device.
                                    type: str
                                  learnMethod:
                                    description: Selects the PAgP learning method. Corresponding CLI - pagp learn-method aggregation
                                      port | physical port.
                                    type: str
                                  mode:
                                    description: Mode.
                                    type: str
                                  portPriority:
                                    description: Assigns a priority so that the selected port is chosen for packet transmission.
                                      Corresponding CLI - pagp port-priority <0-255>.
                                    type: int
                                type: list
                            type: dict
                          minLinks:
                            description: Specifies the minimum number of member ports that must be in the link-up state and
                              bundled in the EtherChannel for the port channel interface to transition to the link-up state.
                              Corresponding CLI - port-channel min-links <2-8>.
                            type: int
                          name:
                            description: Configures the channel group. Corresponding CLI - interface port-channel <1-128>.
                            type: str
                        type: dict
                    type: dict
                type: list
            type: dict
        type: list
    type: dict
  stpGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's stpGlobalConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality configured for STP. Config type STP_GLOBAL is for configuring the global
              settings for STP.
            type: str
          isBackboneFastEnabled:
            description: Enable BackboneFast to detect indirect link failures and to start the STP reconfiguration sooner
              than it would under normal spanning-tree rules. Corresponding CLI - spanning-tree backbonefast.default false.
            type: bool
          isBpduFilterEnabled:
            description: Configure BPDU filtering. Enabling BPDU filtering on PortFast edge-enabled interfaces keeps those
              interfaces that are in a PortFast edge-operational state from sending or receiving BPDUs. Corresponding CLI
              - spanning-tree portfast bpdufilter default.default false.
            type: bool
          isBpduGuardEnabled:
            description: Configure BPDU guard. Enabling BPDU filtering on PortFast edge-enabled interfaces spanning tree shuts
              down ports that are in a PortFast edge-operational state if any BPDU is received on them. Corresponding CLI
              - spanning-tree portfast bpduguard default.default false.
            type: bool
          isEtherChannelGuardEnabled:
            description: Enable EtherChannel guard to detect an EtherChannel misconfiguration between the switch and a connected
              device. A misconfiguration can occur if the switch interfaces are configured in an EtherChannel, but the interfaces
              on the other device are not. A misconfiguration can also occur if the channel parameters are not the same at
              both ends of the EtherChannel. Corresponding CLI - spanning-tree etherchannel guard misconfig.default true.
            type: bool
          isExtendedSystemIdEnabled:
            description: Enable the extended-system ID updates the bridge IDs of all active Spanning Tree Protocol (STP) instances,
              which might change the spanning-tree topology. Corresponding CLI - spanning-tree extend system-id.default true.
            type: bool
          isLoggingEnabled:
            description: Enable STP Logging. Corresponding CLI - spanning-tree logging.default false.
            type: bool
          isLoopGuardEnabled:
            description: Configure loop guard to prevent alternate or root ports from becoming designated ports because of
              a failure that leads to a unidirectional link. Loop guard prevents alternate and root ports from becoming designated
              ports, and spanning tree does not send BPDUs on root or alternate ports. Corresponding CLI - spanning-tree loopguard
              default.default false.
            type: bool
          isUplinkFastEnabled:
            description: Configure UplinkFast which provides fast convergence after a direct link failure and achieves load-balancing
              between redundant Layer 2 links using uplink groups. Corresponding CLI - spanning-tree uplinkfast.default false.
            type: bool
          portFastMode:
            description: Configure portfast on ports so they are moved directly to STP forwarding state without waiting for
              the standard forward-time delay. Corresponding CLI - spanning-tree portfast default.
            type: str
          stpInstances:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's stpInstances.
            suboptions:
              configType:
                description: Type of STP VLAN instances.
                type: str
              items:
                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                elements: dict
                suboptions:
                  configType:
                    description: Type of network functionality under a feature. Config type STP_VLAN is for configuring the
                      per VLAN settings for STP.
                    type: str
                  priority:
                    description: Configure the device priority of a VLAN. Corresponding CLI - spanning-tree vlan <vlan-id>
                      priority <0-61440>. Default 32768 multipleOf 4096.
                    type: int
                  timers:
                    description: Wired Network Devices Id Config Features Intended Layer2 Feature's timers.
                    suboptions:
                      configType:
                        description: Type of network functionality under a feature. Config type STP_TIMERS is for configuring
                          the per-VLAN timers for STP.
                        type: str
                      forwardDelay:
                        description: Configures the maximum-aging time of a VLAN. The maximum-aging time is the number of
                          seconds a switch waits without receiving spanning-tree configuration messages before attempting
                          a reconfiguration. Corresponding CLI - spanning-tree vlan <vlan-id> max-age <6-40>.
                        type: int
                      helloInterval:
                        description: Configure the hello time of a VLAN. The hello time is the time interval between configuration
                          messages that are generated and sent by the root switch. These messages mean that the switch is
                          alive. Corresponding CLI - spanning-tree vlan <vlan-id> hello-time <1-10>.
                        type: int
                      isStpEnabled:
                        description: Enable STP on the VLAN. Corresponding CLI - spanning-tree vlan <vlan-id>. Default true.
                        type: bool
                      maxAge:
                        description: Configure the maximum-aging time of a VLAN. The maximum-aging time is the number of seconds
                          a switch waits without receiving spanning-tree configuration messages before attempting a reconfiguration.
                          Corresponding CLI - spanning-tree vlan <vlan-id> max-age <6-40>.default 20.
                        type: int
                    type: dict
                  vlanId:
                    description: VLAN ID for which STP is configured.
                    type: int
                type: list
            type: dict
          stpMode:
            description: Configure the STP mode. Corresponding CLI - spanning-tree mode mst | pvst | rapid-pvst. PVST - Per-VLAN
              Spanning Tree (PVST) mode is based on the IEEE 802.1D standard and Cisco proprietary extensions. The PVST+ runs
              on each VLAN on the device up to the maximum supported, ensuring that each has a loop-free path through the
              network. RSTP - Rapid per-VLAN Spanning Tree Plus (RSTP) mode is the same as PVST+ except that is uses a rapid
              convergence based on the IEEE 802.1w standard. MST - Multiple Spanning Tree (MST) mode is based on the IEEE
              802.1s standard. You can map multiple VLANs to the same spanning-tree instance, which reduces the number of
              spanning-tree instances that are required to support many VLANs.
            type: str
          transmitHoldCount:
            description: Configure the BPDU burst size by changing the transmit hold count value. Corresponding CLI - spanning-tree
              transmit hold-count <1-20>.default 6.
            type: int
          uplinkFastMaxUpdateRate:
            description: Configure the STP Uplink Fast Max Update Rate to change the rate at which update packets are sent.
              Corresponding CLI - spanning-tree uplinkfast max-update-rate <0-32000>.
            type: int
        type: list
    type: dict
  stpInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's stpInterfaceConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        suboptions:
          bpduFilter:
            description: Configure BPDU filtering on a port. Enabling BPDU filtering on PortFast edge-enabled port keeps the
              port from sending or receiving BPDUs. Corresponding CLI - spanning-tree bpduguard enable | disable.
            type: str
          bpduGuard:
            description: Configures BPDU guard. When BPDU filtering is enabled on PortFast edge-enabled port, spanning tree
              shuts down the port if any BPDU is received on it.
            type: str
          configType:
            description: Type of network functionality under a feature. Config type STP_INTERFACE is for configuring STP on
              an interface.
            type: str
          guardMode:
            description: Enable loop guard or root guard on the interface. Corresponding CLI - spanning-tree guard loop |
              none | root. LOOP - Enables loop guard on the interface. ROOT - Enables root guard on the interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the
              list of interfaces on a device.example GigabitEthernet1/0/1.
            type: str
          pathCost:
            description: Configure the cost for an interface. Corresponding CLI - spanning-tree cost <1-200000000>.
            type: int
          portFastMode:
            description: Configure the portFast mode for an interface. Corresponding CLI - spanning-tree portfast disable
              | trunk | network | edge | edge trunk. DISABLE - Disable portFast for this interface. EDGE - Enable edge behavior
              on a Layer 2 access port connected to an end workstation or server. EDGE_TRUNK - Enable edge behavior on a trunk
              port. Use this keyword if the link is a trunk. NETWORK - Configure the port as a network port. Ports that are
              connected to Layer 2 switches and bridges can be configured as network ports. If Bridge Assurance is enabled
              globally, it automatically gets enabled on a spanning tree network port. TRUNK - Enable portfast on a trunk
              port.
            type: str
          portVlanCostSettings:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's portVlanCostSettings.
            suboptions:
              configType:
                description: Type of STP Cost Settings.
                type: str
              items:
                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                elements: dict
                suboptions:
                  configType:
                    description: Type of network functionality under a feature. Config type STP_INTERFACE_VLAN_COST is for
                      configuring per VLAN cost on an interface.
                    type: str
                  cost:
                    description: Configure the cost for the VLANs. Corresponding CLI - spanning-tree vlan cost <1-200000000>.
                    type: int
                  vlans:
                    description: VLANs can be comma separated and/or a range like '2,4-5,7,10-20'.
                    type: str
                type: list
            type: dict
          portVlanPrioritySettings:
            description: Wired Network Devices Id Config Features Intended Layer2 Feature's portVlanPrioritySettings.
            suboptions:
              configType:
                description: Type of STP Priority Settings.
                type: str
              items:
                description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
                elements: dict
                suboptions:
                  configType:
                    description: ConfigType.
                    type: str
                  priority:
                    description: Configures the port priority for the VLANs. Corresponding CLI - spanning-tree vlan port-priority
                      <0-240>.multipleOf 16.
                    type: int
                  vlans:
                    description: VLANs can be comma separated and/or a range like '2,4-5,7,10-20'.
                    type: str
                type: list
            type: dict
          priority:
            description: Configures port priority for an interface. If a loop occurs, spanning tree uses port priority when
              selecting an interface to put into the forwarding state. Assign higher priority values (lower numerical values)
              to interfaces that you want selected first and lower priority values (higher numerical values) that you want
              selected last. If all interfaces have the same priority value, spanning tree puts the interface with the lowest
              interface number in the forwarding state and blocks the other interfaces. Corresponding CLI - spanning-tree
              port-priority <0-240>.multipleOf 16.
            type: int
        type: dict
    type: dict
  switchportInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's switchportInterfaceConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          accessVlan:
            description: Set the VLAN for untagged traffic when the interface is in access mode. Corresponding CLI - switchport
              access vlan <1-4094>.
            type: int
          adminStatus:
            description: Configured the admin state of the interface as either 'UP' or 'DOWN'. Corresponding CLI - no shutdown.default
              UP.
            type: str
          configType:
            description: Type of network functionality under a feature. Config type SWITCHPORT_INTERFACE is for configuring
              switchport settings on an interface.
            type: str
          description:
            description: Configure the description of the interface. It cannot include non-ASCII characters. Corresponding
              CLI - description .
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the
              list of interfaces on a device.example GigabitEthernet1/0/1.
            type: str
          mode:
            description: Set the administrative mode for the interface. Corresponding CLI - switchport mode access | trunk
              | dynamic auto | dynamic desirable | dot1q-tunnel .
            type: str
          nativeVlan:
            description: Set the native VLAN for IEEE 802.1Q trunks. Corresponding CLI - switchport trunk native vlan <1-4094>.
            type: int
          trunkAllowedVlans:
            description: Configure the list of VLANs allowed on a trunk interface. Allowed VLANs should be between 1 and 4094.
              VLANs can be comma separated and/or a range like '2,4-5,7,10-20'. Corresponding CLI - switchport trunk allowed
              vlan 10, 20, 21-24 | all | none.
            type: str
          voiceVlan:
            description: Enable the access port to carry IP voice traffic from an IP phone. All voice traffic is on the specified
              VLAN. Corresponding CLI - switchport voice vlan <1-4094>.
            type: int
        type: list
    type: dict
  trunkInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's trunkInterfaceConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type TRUNK_INTERFACE is for configuring trunk
              settings on an interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the
              list of interfaces on a device.
            type: str
          isDtpNegotiationEnabled:
            description: Configure whether or not the interface supports negotiation of the trunk encapsulation. The switchport
              nonegotiate command is issued to prevent DTP (negotiation) packets from being sent out the interface. Corresponding
              CLI - switchport nonegotiate. Default true.
            type: bool
          isProtected:
            description: A protected port does not forward any traffic (unicast, multicast, or broadcast) to any other port
              that is also a protected port. Data traffic cannot be forwarded between protected ports at Layer 2; all data
              traffic passing between protected ports must be forwarded through a Layer 3 device. Forwarding behavior between
              a protected port and a non-protected port proceeds as usual. Corresponding CLI - switchport protected.default
              false.
            type: bool
          pruneEligibleVlans:
            description: Configure the prune eligibility list. By default, all VLANs are allowed on a trunk and all VLANs
              (between 2 and 1001, inclusive) are eligible for pruning if pruning is enabled globally with the vtp pruning
              command. If a prune eligibility list is configured, then only those VLANs on the list are eligible for pruning.
              Corresponding CLI - switchport trunk pruning vlan 10, 20, 21-24 | none.
            type: str
        type: list
    type: dict
  vlanConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's vlanConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality configured for VLAN. Config type VLAN is for configuring VLANs.
            type: str
          isVlanEnabled:
            description: Enables or disables the VLAN switching. Corresponding CLI - shutdown. Default true.
            type: bool
          name:
            description: Configure the name of the VLAN. VTP version VTPv1 and VTPv2 supports VLAN name of 32 character length,
              VTP version VTPv3 supports up to 128 characters. The recommended name length is 20 characters. If no name is
              entered for the VLAN, the default is to append the VLAN ID with leading zeros to the word VLAN. For example,
              VLAN0004 is a default VLAN name for VLAN 4. Corresponding CLI - name <vlan-name>. Example iot_vlan.
            type: str
          vlanId:
            description: VLAN ID is the identifier for a VLAN.
            type: int
        type: list
    type: dict
  vtpGlobalConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's vtpGlobalConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality configured for VTP. Config type VTP_GLOBAL is for configuring the global
              settings for VTP.
            type: str
          configurationFileName:
            description: Configures the ASCII filename of the IFS file system file where the VTP configuration is stored.
              By default, it is stored in the vlan.dat file. Corresponding CLI - vtp filename <file-name>.example flash saved_vtp_config.
            type: str
          domainName:
            description: Configures the VTP administrative domain name. Global VLAN configuration changes are propagated to
              the devices that have the same VTP domain name. When the domain name is not specified, VLAN information is not
              propagated over the network. Once the domain name is configured, it cannot be deleted; it can only be changed.
              Devices in VTP transparent mode do not exchange VTP messages with other devices, so a VTP domain name does not
              need to be configured for them. Corresponding CLI - vtp domain <domain-name>.
            type: str
          isPruningEnabled:
            description: Enables pruning in the VTP administrative domain. VTP pruning blocks unneeded flooded traffic for
              prune-eligible VLANs on trunk ports. It increases network available bandwidth by restricting flooded traffic
              to those trunk links that the traffic must use to reach the destination devices. VLAN 1 and VLANs 1002 to 1005
              are always pruning-ineligible; traffic from these VLANs cannot be pruned. Extended-range VLANs (VLAN IDs higher
              than 1005) are also pruning-ineligible. VTP pruning can be configured only on a VTP server. Corresponding CLI
              - vtp pruning.default false.
            type: bool
          mode:
            description: Configures the device for VTP mode. Corresponding CLI - vtp mode. SERVER - Any VLAN configuration
              changes in this mode are propagated to all devices in the VTP domain. VTP servers advertise their VLAN configurations
              to other devices in the same VTP domain and synchronize their VLAN configurations with other devices based on
              advertisements received over trunk links. CLIENT - VLANs cannot be configured in this mode but VTP updates are
              transmitted as well as received. TRANSPARENT - VLANs can be configured in this mode but the changes are not
              sent to other devices in the domain, and they affect only the individual device. VTP updates are not generated
              but the received updates are forwarded. However, in VTP version 2 or version 3, transparent devices do forward
              VTP advertisements that they receive from other devices. OFF - VLANs can be configured in this mode but VTP
              updates are neither generated nor forwarded.
            type: str
          sourceInterface:
            description: Configures an interface as the preferred source for VTP updates from this device. The IP address
              of the specified interface becomes the VTP IP updater address, and can be used to determine which VTP server
              last updated the VLAN database in the VTP domain. Corresponding CLI - vtp interface <interface-name>.example
              GigabitEthernet1/0/1.
            type: str
          version:
            description: Configures VTP version on the device. Corresponding CLI - vtp version. VERSION_2 supports unrecognized
              TLV. VERSION_3 supports primary and secondary servers, private VLANs, propagation of extended VLANs (VLAN IDs
              1006-4094), propagation of Multiple Spanning Tree (MST) information. VTP domain name needs to be configured
              for VTP version 3.
            type: str
        type: list
    type: dict
  vtpInterfaceConfig:
    description: Wired Network Devices Id Config Features Intended Layer2 Feature's vtpInterfaceConfig.
    suboptions:
      items:
        description: Wired Network Devices Id Config Features Intended Layer2 Feature's items.
        elements: dict
        suboptions:
          configType:
            description: Type of network functionality under a feature. Config type VTP_INTERFACE is for configuring VTP in
              an interface.
            type: str
          interfaceName:
            description: Interface name. The API /intent/api/v1/interface/network-device/{deviceId} can be used to get the
              list of interfaces on a device.example GigabitEthernet1/0/1.
            type: str
          isVtpEnabled:
            description: Enables or disables VTP per interface. When VTP is disabled on a trunk interface, it drops incoming
              VTP packets and prevents VTP advertisements on this particular trunk. Corresponding CLI - vtp. Default true.
            type: bool
        type: list
    type: dict
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wired CreateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
    description: Complete reference of the CreateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!create-configurations-for-an-intended-layer-2-feature-on-a-wired-device
  - name: Cisco DNA Center documentation for Wired DeleteConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
    description: Complete reference of the DeleteConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-configurations-for-an-intended-layer-2-feature-on-a-wired-device
  - name: Cisco DNA Center documentation for Wired UpdateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice
    description: Complete reference of the UpdateConfigurationsForAnIntendedLayer2FeatureOnAWiredDevice API.
    link: https://developer.cisco.com/docs/dna-center/#!update-configurations-for-an-intended-layer-2-feature-on-a-wired-device
notes:
  - SDK Method used are
    wired.Wired.create_configurations_for_an_intended_layer2_feature_on_a_wired_device,
    wired.Wired.delete_configurations_for_an_intended_layer2_feature_on_a_wired_device,
    wired.Wired.update_configurations_for_an_intended_layer2_feature_on_a_wired_device,
  - Paths used are
    post /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2/{feature},
    delete /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2/{feature},
    put /dna/intent/api/v1/wired/networkDevices/{id}/configFeatures/intended/layer2/{feature},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.wired_network_devices_id_config_features_intended_layer2_feature:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    feature: string
    id: string
- name: Create
  cisco.dnac.wired_network_devices_id_config_features_intended_layer2_feature:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cdpGlobalConfig:
      items:
        - configType: string
          holdTime: 0
          isAdvertiseV2Enabled: true
          isCdpEnabled: true
          isLogDuplexMismatchEnabled: true
          timer: 0
    cdpInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isCdpEnabled: true
          isLogDuplexMismatchEnabled: true
    dhcpSnoopingGlobalConfig:
      items:
        - configType: string
          databaseAgent:
            agentUrl: string
            configType: string
            timeout: 0
            writeDelay: 0
          dhcpSnoopingVlans: string
          isDhcpSnoopingEnabled: true
          isGleaningEnabled: true
          proxyBridgeVlans: string
    dhcpSnoopingInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isTrustedInterface: true
          messageRateLimit: 0
    dot1xGlobalConfig:
      items:
        - authenticationConfigMode: string
          configType: string
          isDot1xEnabled: true
    dot1xInterfaceConfig:
      items:
        - authenticationOrder:
            configType: string
            items:
              - string
          configType: string
          interfaceName: string
    feature: string
    id: string
    igmpSnoopingGlobalConfig:
      items:
        - configType: string
          igmpSnoopingVlanSettings:
            configType: string
            items:
              - configType: string
                igmpSnoopingVlanMrouters:
                  configType: string
                  items:
                    - configType: string
                      interfaceName: string
                isIgmpSnoopingEnabled: true
                isImmediateLeaveEnabled: true
                isQuerierEnabled: true
                querierAddress: string
                querierQueryInterval: 0
                querierVersion: string
                vlanId: 0
          isIgmpSnoopingEnabled: true
          isQuerierEnabled: true
          querierAddress: string
          querierQueryInterval: 0
          querierVersion: string
    lldpGlobalConfig:
      items:
        - configType: string
          holdTime: 0
          isLldpEnabled: true
          reinitializationDelay: 0
          timer: 0
    lldpInterfaceConfig:
      items:
        - adminStatus: string
          configType: string
          interfaceName: string
    mabInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isMabEnabled: true
    mldSnoopingGlobalConfig:
      items:
        - configType: string
          isMldSnoopingEnabled: true
          isQuerierEnabled: true
          isSuppressListenerMessagesEnabled: true
          mldSnoopingVlanSettings:
            configType: string
            items:
              - configType: string
                isImmediateLeaveEnabled: true
                isMldSnoopingEnabled: true
                isQuerierEnabled: true
                mldSnoopingVlanMrouters:
                  configType: string
                  items:
                    - configType: string
                      interfaceName: string
                querierAddress: string
                querierQueryInterval: 0
                querierVersion: string
                vlanId: 0
          querierAddress: string
          querierQueryInterval: 0
          querierVersion: string
    portChannelConfig:
      items:
        - configType: string
          isAutoEnabled: true
          lacpSystemPriority: 0
          loadBalancingMethod: string
          portchannels:
            configType: string
            items:
              - AnyOf:
                  EtherchannelConfig:
                    configType: string
                    memberPorts:
                      configType: string
                      items:
                        - configType: string
                          interfaceName: string
                          mode: string
                    minLinks: 0
                    name: string
                  LacpPortchannelConfig:
                    configType: string
                    memberPorts:
                      configType: string
                      items:
                        - configType: string
                          interfaceName: string
                          mode: string
                          portPriority: 0
                          rate: 0
                    minLinks: 0
                    name: string
                  PagpPortchannelConfig:
                    configType: string
                    memberPorts:
                      configType: string
                      items:
                        - configType: string
                          interfaceName: string
                          learnMethod: string
                          mode: string
                          portPriority: 0
                    minLinks: 0
                    name: string
    stpGlobalConfig:
      items:
        - configType: string
          isBackboneFastEnabled: true
          isBpduFilterEnabled: true
          isBpduGuardEnabled: true
          isEtherChannelGuardEnabled: true
          isExtendedSystemIdEnabled: true
          isLoggingEnabled: true
          isLoopGuardEnabled: true
          isUplinkFastEnabled: true
          portFastMode: string
          stpInstances:
            configType: string
            items:
              - configType: string
                priority: 0
                timers:
                  configType: string
                  forwardDelay: 0
                  helloInterval: 0
                  isStpEnabled: true
                  maxAge: 0
                vlanId: 0
          stpMode: string
          transmitHoldCount: 0
          uplinkFastMaxUpdateRate: 0
    stpInterfaceConfig:
      items:
        bpduFilter: string
        bpduGuard: string
        configType: string
        guardMode: string
        interfaceName: string
        pathCost: 0
        portFastMode: string
        portVlanCostSettings:
          configType: string
          items:
            - configType: string
              cost: 0
              vlans: string
        portVlanPrioritySettings:
          configType: string
          items:
            - configType: string
              priority: 0
              vlans: string
        priority: 0
    switchportInterfaceConfig:
      items:
        - accessVlan: 0
          adminStatus: string
          configType: string
          description: string
          interfaceName: string
          mode: string
          nativeVlan: 0
          trunkAllowedVlans: string
          voiceVlan: 0
    trunkInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isDtpNegotiationEnabled: true
          isProtected: true
          pruneEligibleVlans: string
    vlanConfig:
      items:
        - configType: string
          isVlanEnabled: true
          name: string
          vlanId: 0
    vtpGlobalConfig:
      items:
        - configType: string
          configurationFileName: string
          domainName: string
          isPruningEnabled: true
          mode: string
          sourceInterface: string
          version: string
    vtpInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isVtpEnabled: true
- name: Update by id
  cisco.dnac.wired_network_devices_id_config_features_intended_layer2_feature:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    cdpGlobalConfig:
      items:
        - configType: string
          holdTime: 0
          isAdvertiseV2Enabled: true
          isCdpEnabled: true
          isLogDuplexMismatchEnabled: true
          timer: 0
    cdpInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isCdpEnabled: true
          isLogDuplexMismatchEnabled: true
    dhcpSnoopingGlobalConfig:
      items:
        - configType: string
          databaseAgent:
            agentUrl: string
            configType: string
            timeout: 0
            writeDelay: 0
          dhcpSnoopingVlans: string
          isDhcpSnoopingEnabled: true
          isGleaningEnabled: true
          proxyBridgeVlans: string
    dhcpSnoopingInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isTrustedInterface: true
          messageRateLimit: 0
    dot1xGlobalConfig:
      items:
        - authenticationConfigMode: string
          configType: string
          isDot1xEnabled: true
    dot1xInterfaceConfig:
      items:
        - authenticationOrder:
            configType: string
            items:
              - string
          configType: string
          interfaceName: string
    feature: string
    id: string
    igmpSnoopingGlobalConfig:
      items:
        - configType: string
          igmpSnoopingVlanSettings:
            configType: string
            items:
              - configType: string
                igmpSnoopingVlanMrouters:
                  configType: string
                  items:
                    - configType: string
                      interfaceName: string
                isIgmpSnoopingEnabled: true
                isImmediateLeaveEnabled: true
                isQuerierEnabled: true
                querierAddress: string
                querierQueryInterval: 0
                querierVersion: string
                vlanId: 0
          isIgmpSnoopingEnabled: true
          isQuerierEnabled: true
          querierAddress: string
          querierQueryInterval: 0
          querierVersion: string
    lldpGlobalConfig:
      items:
        - configType: string
          holdTime: 0
          isLldpEnabled: true
          reinitializationDelay: 0
          timer: 0
    lldpInterfaceConfig:
      items:
        - adminStatus: string
          configType: string
          interfaceName: string
    mabInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isMabEnabled: true
    mldSnoopingGlobalConfig:
      items:
        - configType: string
          isMldSnoopingEnabled: true
          isQuerierEnabled: true
          isSuppressListenerMessagesEnabled: true
          mldSnoopingVlanSettings:
            configType: string
            items:
              - configType: string
                isImmediateLeaveEnabled: true
                isMldSnoopingEnabled: true
                isQuerierEnabled: true
                mldSnoopingVlanMrouters:
                  configType: string
                  items:
                    - configType: string
                      interfaceName: string
                querierAddress: string
                querierQueryInterval: 0
                querierVersion: string
                vlanId: 0
          querierAddress: string
          querierQueryInterval: 0
          querierVersion: string
    portChannelConfig:
      items:
        - configType: string
          isAutoEnabled: true
          lacpSystemPriority: 0
          loadBalancingMethod: string
          portchannels:
            configType: string
            items:
              - AnyOf:
                  EtherchannelConfig:
                    configType: string
                    memberPorts:
                      configType: string
                      items:
                        - configType: string
                          interfaceName: string
                          mode: string
                    minLinks: 0
                    name: string
                  LacpPortchannelConfig:
                    configType: string
                    memberPorts:
                      configType: string
                      items:
                        - configType: string
                          interfaceName: string
                          mode: string
                          portPriority: 0
                          rate: 0
                    minLinks: 0
                    name: string
                  PagpPortchannelConfig:
                    configType: string
                    memberPorts:
                      configType: string
                      items:
                        - configType: string
                          interfaceName: string
                          learnMethod: string
                          mode: string
                          portPriority: 0
                    minLinks: 0
                    name: string
    stpGlobalConfig:
      items:
        - configType: string
          isBackboneFastEnabled: true
          isBpduFilterEnabled: true
          isBpduGuardEnabled: true
          isEtherChannelGuardEnabled: true
          isExtendedSystemIdEnabled: true
          isLoggingEnabled: true
          isLoopGuardEnabled: true
          isUplinkFastEnabled: true
          portFastMode: string
          stpInstances:
            configType: string
            items:
              - configType: string
                priority: 0
                timers:
                  configType: string
                  forwardDelay: 0
                  helloInterval: 0
                  isStpEnabled: true
                  maxAge: 0
                vlanId: 0
          stpMode: string
          transmitHoldCount: 0
          uplinkFastMaxUpdateRate: 0
    stpInterfaceConfig:
      items:
        bpduFilter: string
        bpduGuard: string
        configType: string
        guardMode: string
        interfaceName: string
        pathCost: 0
        portFastMode: string
        portVlanCostSettings:
          configType: string
          items:
            - configType: string
              cost: 0
              vlans: string
        portVlanPrioritySettings:
          configType: string
          items:
            - configType: string
              priority: 0
              vlans: string
        priority: 0
    switchportInterfaceConfig:
      items:
        - accessVlan: 0
          adminStatus: string
          configType: string
          description: string
          interfaceName: string
          mode: string
          nativeVlan: 0
          trunkAllowedVlans: string
          voiceVlan: 0
    trunkInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isDtpNegotiationEnabled: true
          isProtected: true
          pruneEligibleVlans: string
    vlanConfig:
      items:
        - configType: string
          isVlanEnabled: true
          name: string
          vlanId: 0
    vtpGlobalConfig:
      items:
        - configType: string
          configurationFileName: string
          domainName: string
          isPruningEnabled: true
          mode: string
          sourceInterface: string
          version: string
    vtpInterfaceConfig:
      items:
        - configType: string
          interfaceName: string
          isVtpEnabled: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_profiles_id_site_tags
short_description: Resource module for Wireless Profiles Id Site Tags
description:
  - Manage operations update and delete of the resource Wireless Profiles Id Site Tags. - > This endpoint enables the deletion
    of a specific `Site Tag` associated with a given `Wireless Profile`. This API requires the `id` of the `Wireless Profile`
    and the `siteTagId` of the `Site Tag` to be provided as path parameters. - > This endpoint allows updating the details
    of a specific `Site Tag` associated with a given `Wireless Profile`. The `id` of the `Wireless Profile` and the `siteTagId`
    of the Site Tag must be provided as path parameters, and the request body should contain the updated `Site Tag` details.
    The `siteTagName` cannot be modified through this endpoint.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  apProfileName:
    description: Ap Profile Name.
    type: str
  flexProfileName:
    description: Flex Profile Name.
    type: str
  id:
    description: Id path parameter. Wireless Profile id.
    type: str
  siteIds:
    description: Site Ids.
    elements: str
    type: list
  siteTagId:
    description: SiteTagId path parameter. Site Tag Id.
    type: str
  siteTagName:
    description: Use English letters, numbers, special characters except <, /, '.*', ? and leading/trailing space.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless DeleteASpecificSiteTagFromAWirelessProfile
    description: Complete reference of the DeleteASpecificSiteTagFromAWirelessProfile API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-a-specific-site-tag-from-a-wireless-profile
  - name: Cisco DNA Center documentation for Wireless UpdateASpecificSiteTagForAWirelessProfile
    description: Complete reference of the UpdateASpecificSiteTagForAWirelessProfile API.
    link: https://developer.cisco.com/docs/dna-center/#!update-a-specific-site-tag-for-a-wireless-profile
notes:
  - SDK Method used are
    wireless.Wireless.delete_a_specific_site_tag_from_a_wireless_profile,
    wireless.Wireless.update_a_specific_site_tag_for_a_wireless_profile,
  - Paths used are
    delete /dna/intent/api/v1/wirelessProfiles/{id}/siteTags/{siteTagId},
    put /dna/intent/api/v1/wirelessProfiles/{id}/siteTags/{siteTagId},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.wireless_profiles_id_site_tags:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
    siteTagId: string
- name: Update by id
  cisco.dnac.wireless_profiles_id_site_tags:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    apProfileName: string
    flexProfileName: string
    id: string
    siteIds:
      - string
    siteTagId: string
    siteTagName: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: device_configurations_export
short_description: Resource module for Device Configurations Export
description:
  - Manage operation create of the resource Device Configurations Export.
  - Export Device configuration for every device that is provided will be included in an encrypted zip file.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deviceId:
    description: UUIDs of the devices for which configurations need to be exported.
    elements: str
    type: list
  password:
    description: Password for the zip file to protect exported configurations. Must contain, at minimum 8 characters, one
      lowercase letter, one uppercase letter, one number, one special character(-=;,./~!@#$%^&*()_+{}| ?). It may not contain
      white space or the characters <>.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Configuration Archive ExportDeviceConfigurations
    description: Complete reference of the ExportDeviceConfigurations API.
    link: https://developer.cisco.com/docs/dna-center/#!export-device-configurations
notes:
  - SDK Method used are
    configuration_archive.ConfigurationArchive.export_device_configurations,
  - Paths used are
    post /dna/intent/api/v1/network-device-archive/cleartext,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.device_configurations_export:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deviceId:
      - string
    password: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: discoverys
short_description: Resource module for Discoverys
description:
  - Manage operations create, update and delete of the resource Discoverys. - > This API creates a discovery. The response
    includes a task url that provides access to the task's details. By accessing this URL, users will receive a response containing
    a resultLocation attribute, which provides details of the discovery settings that was created, including the discovery
    id.
  - API to delete discovery by the given discovery id. - > API to edit the discovery details of the given discovery id. Updating
    the discovery details while the discovery is in progress is not allowed.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  credentials:
    description: Discoverys's credentials.
    suboptions:
      cli:
        description: Discoverys's cli.
        suboptions:
          description:
            description: Description for CLI credential.
            type: str
          globalCredentialIdList:
            description: List of global credential ids.
            elements: str
            type: list
          protocolOrder:
            description: Connection protocol for the device. Default value is SSH.
            type: str
          username:
            description: CLI username to login to the device.
            type: str
        type: dict
      httpRead:
        description: Discoverys's httpRead.
        suboptions:
          description:
            description: Description for HTTP(S) read credentials.
            type: str
          globalCredentialIdList:
            description: List of global credential ids.
            elements: str
            type: list
          port:
            description: Number of the TCP/UDP port that is used for HTTPS traffic. The default is port number 443 (the well-known
              port for HTTPS).
            type: int
          protocol:
            description: Protocol for HTTP credentials.
            type: str
          username:
            description: Name that is used to authenticate the HTTPS connection. Username cannot contain spaces or angle brackets
              (< >).
            type: str
        type: dict
      httpWrite:
        description: Discoverys's httpWrite.
        suboptions:
          description:
            description: Description for HTTP(S) write credentials.
            type: str
          globalCredentialIdList:
            description: List of global credential ids.
            elements: str
            type: list
          port:
            description: Number of the TCP/UDP port that is used for HTTPS traffic. The default is port number 443 (the well-known
              port for HTTPS).
            type: int
          protocol:
            description: Protocol for HTTP credentials.
            type: str
          username:
            description: Name that is used to authenticate the HTTPS connection. Username cannot contain spaces or angle brackets
              (< >).
            type: str
        type: dict
      netconf:
        description: Discoverys's netconf.
        suboptions:
          description:
            description: Description for NETCONF credential.
            type: str
          globalCredentialIdList:
            description: List of global credential ids.
            elements: str
            type: list
          port:
            description: Netconf Port of the device. Recommended port number is 830.
            type: int
        type: dict
      snmp:
        description: Discoverys's snmp.
        suboptions:
          retries:
            description: The number of times to repeat the failed SNMP polling request after a timeout. Max value supported
              is 3. Default is Global SNMP retry (if exists) or 3.
            type: int
          snmpV2Read:
            description: Discoverys's snmpV2Read.
            suboptions:
              description:
                description: Description for SNMP read-only community.
                type: str
              globalCredentialIdList:
                description: List of global credential ids.
                elements: str
                type: list
            type: dict
          snmpV2Write:
            description: Discoverys's snmpV2Write.
            suboptions:
              description:
                description: Description for SNMP read-write community.
                type: str
              globalCredentialIdList:
                description: List of global credential ids.
                elements: str
                type: list
            type: dict
          snmpV3:
            description: Discoverys's snmpV3.
            suboptions:
              authType:
                description: SNMP authentication type. Required if the SNMP security mode is AUTHPRIV or AUTHNOPRIV.
                type: str
              description:
                description: Description for SNMP V3 credential.
                type: str
              globalCredentialIdList:
                description: List of global credential ids.
                elements: str
                type: list
              mode:
                description: Security level that an SNMP message requires.
                type: str
              privacyType:
                description: SNMP privacy type. Required if the SNMP mode is AUTHPRIV.
                type: str
              username:
                description: Username associated with the SNMPv3 settings. The username can only contain letters, numbers
                  and -_.@ characters.
                type: str
            type: dict
          timeout:
            description: The interval (in seconds) after which SNMP failure to respond to the polling request generates a
              timeout. Max value supported is 300. Default is Global SNMP timeout (if exists) or 5.
            type: int
        type: dict
    type: dict
  discoveryTypeDetails:
    description: Discoverys's discoveryTypeDetails.
    suboptions:
      cidrAddress:
        description: Discoverys's cidrAddress.
        suboptions:
          cidrPrefix:
            description: CIDR prefix for the IP address.
            type: str
          cidrSuffix:
            description: The CIDR suffix length indicates the number of bits for host addresses, following the prefix. For
              IPv4, supported lengths range from 20 to 30, where default is 30. For IPv6, they range from 116 to 126, where
              default is 126.
            type: int
        type: dict
      hopCount:
        description: This field defines the CDP level, indicating the number of hops from the seed device to scan. Acceptable
          values range from 1 to 16, with a default of 16. For instance, a CDP level of 3 means scanning will include up to
          three hops from the seed device.
        type: int
      ipAddress:
        description: IPv4 or IPv6 address of the device.
        type: str
      range:
        description: Discoverys's range.
        elements: dict
        suboptions:
          ipAddressEnd:
            description: End IP address of devices to be discovered.
            type: str
          ipAddressStart:
            description: Start IP address of the devices to be discovered.
            type: str
        type: list
      subnetFilter:
        description: Discoverys's subnetFilter.
        suboptions:
          cidrAddress:
            description: Discoverys's cidrAddress.
            suboptions:
              cidrPrefix:
                description: CIDR prefix for the IP address.
                type: str
              cidrSuffix:
                description: The CIDR suffix length indicates the number of bits for host addresses, following the prefix.
                  For IPv4, supported lengths range from 20 to 30, where default is 30. For IPv6, they range from 116 to 126,
                  where default is 126.
                type: int
            type: dict
          ipAddress:
            description: IPv4 or IPv6 address of the device.
            type: str
        type: dict
      type:
        description: Type of the discovery.
        type: str
    type: dict
  id:
    description: Id path parameter. The id of the discovery.
    type: str
  managementIpSelectionMethod:
    description: When Catalyst Center discovers a device, it uses one of the device's IP addresses as the preferred management
      IP address for the device. The IP address can be that of a built-in management interface of the device, another physical
      interface, or a logical interface like Loopback0. You can configure Catalyst Center to log the device's loopback IP
      address as the preferred management IP address, provided the IP address is reachable from Catalyst Center.
    type: str
  name:
    description: The name of the discovery job being created. This will be a unique name.
    type: str
  onlyNewDevice:
    description: This flag indicates to discover only new devices that are not in inventory. If set to true, only devices
      that are not in the inventory will be discovered. If set to false, devices that already exist in the inventory will
      not be listed in the discovered devices list.
    type: bool
  updateManagementIp:
    description: This flag indicates if the management IP address of existing devices to be updated as part of this discovery.
      If set false devices get discovered with the existing management IP address. If set true it overwrites the management
      IP address with the new IP address used in discovery.
    type: bool
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices CreatesDiscovery
    description: Complete reference of the CreatesDiscovery API.
    link: https://developer.cisco.com/docs/dna-center/#!creates-discovery
  - name: Cisco DNA Center documentation for Devices DeletesDiscoveryById
    description: Complete reference of the DeletesDiscoveryById API.
    link: https://developer.cisco.com/docs/dna-center/#!deletes-discovery-by-id
  - name: Cisco DNA Center documentation for Devices EditsDiscovery
    description: Complete reference of the EditsDiscovery API.
    link: https://developer.cisco.com/docs/dna-center/#!edits-discovery
notes:
  - SDK Method used are
    devices.Devices.creates_discovery,
    devices.Devices.deletes_discovery_by_id,
    devices.Devices.edits_discovery,
  - Paths used are
    post /dna/intent/api/v1/discoverys,
    delete /dna/intent/api/v1/discoverys/{id},
    put /dna/intent/api/v1/discoverys/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.discoverys:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    credentials:
      cli:
        description: string
        globalCredentialIdList:
          - string
        protocolOrder: string
        username: string
      httpRead:
        description: string
        globalCredentialIdList:
          - string
        port: 0
        protocol: string
        username: string
      httpWrite:
        description: string
        globalCredentialIdList:
          - string
        port: 0
        protocol: string
        username: string
      netconf:
        description: string
        globalCredentialIdList:
          - string
        port: 0
      snmp:
        retries: 0
        snmpV2Read:
          description: string
          globalCredentialIdList:
            - string
        snmpV2Write:
          description: string
          globalCredentialIdList:
            - string
        snmpV3:
          authType: string
          description: string
          globalCredentialIdList:
            - string
          mode: string
          privacyType: string
          username: string
        timeout: 0
    discoveryTypeDetails:
      cidrAddress:
        cidrPrefix: string
        cidrSuffix: 0
      hopCount: 0
      ipAddress: string
      range:
        - ipAddressEnd: string
          ipAddressStart: string
      subnetFilter:
        cidrAddress:
          cidrPrefix: string
          cidrSuffix: 0
        ipAddress: string
      type: string
    managementIpSelectionMethod: string
    name: string
    onlyNewDevice: true
    updateManagementIp: true
- name: Delete by id
  cisco.dnac.discoverys:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.discoverys:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    credentials:
      cli:
        description: string
        globalCredentialIdList:
          - string
        protocolOrder: string
        username: string
      httpRead:
        description: string
        globalCredentialIdList:
          - string
        port: 0
        protocol: string
        username: string
      httpWrite:
        description: string
        globalCredentialIdList:
          - string
        port: 0
        protocol: string
        username: string
      netconf:
        description: string
        globalCredentialIdList:
          - string
        port: 0
      snmp:
        retries: 0
        snmpV2Read:
          description: string
          globalCredentialIdList:
            - string
        snmpV2Write:
          description: string
          globalCredentialIdList:
            - string
        snmpV3:
          authType: string
          description: string
          globalCredentialIdList:
            - string
          mode: string
          privacyType: string
          username: string
        timeout: 0
    discoveryTypeDetails:
      cidrAddress:
        cidrPrefix: string
        cidrSuffix: 0
      hopCount: 0
      ipAddress: string
      range:
        - ipAddressEnd: string
          ipAddressStart: string
      subnetFilter:
        cidrAddress:
          cidrPrefix: string
          cidrSuffix: 0
        ipAddress: string
      type: string
    id: string
    managementIpSelectionMethod: string
    onlyNewDevice: true
    updateManagementIp: true
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_controllers_network_device_id_ap_authorization_lists_info
short_description: Information module for Wireless Controllers Network Device Id Ap Authorization Lists
description:
  - Get all Wireless Controllers Network Device Id Ap Authorization Lists. - > This API allows the user to get an AP Authorization
    List details configured for the given provisioned network device Id. Obtain the network device ID value by using the API
    GET call '/dna/intent/api/v1/network-device/ip- address/${ipAddress}'.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  networkDeviceId:
    description:
      - NetworkDeviceId path parameter. Network Device ID.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless GetAPAuthorizationListByNetworkDeviceId
    description: Complete reference of the GetAPAuthorizationListByNetworkDeviceId API.
    link: https://developer.cisco.com/docs/dna-center/#!get-ap-authorization-list-by-network-device-id
notes:
  - SDK Method used are
    wireless.Wireless.get_ap_authorization_list_by_network_device_id,
  - Paths used are
    get /dna/intent/api/v1/wirelessControllers/{networkDeviceId}/apAuthorizationLists,
"""

EXAMPLES = r"""
---
- name: Get all Wireless Controllers Network Device Id Ap Authorization Lists
  cisco.dnac.wireless_controllers_network_device_id_ap_authorization_lists_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    networkDeviceId: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "networkDeviceId": "string",
        "apAuthorizationListName": "string",
        "localAuthorization": {
          "apMacEntries": [
            "string"
          ],
          "apSerialNumberEntries": [
            "string"
          ]
        },
        "remoteAuthorization": {
          "aaaServers": [
            "string"
          ],
          "authorizeApWithMac": true,
          "authorizeApWithSerialNumber": true
        }
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_module_info
short_description: Information module for Network Device Module
description:
  - Get all Network Device Module.
  - Get Network Device Module by id.
  - Returns Module info by 'module id'. - > Returns modules by specified device id. The API returns a paginated response based
    on 'limit' and 'offset' parameters, allowing up to 500 records per page. 'limit' specifies the number of records, and
    'offset' sets the starting point using 1-based indexing. Use /dna/intent/api/v1/network-device/module/count API to get
    the total record count. For data sets over 500 records, make multiple calls, adjusting 'limit' and 'offset' to retrieve
    all records incrementally.
version_added: '3.1.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  deviceId:
    description:
      - DeviceId query parameter.
    type: str
  limit:
    description:
      - Limit query parameter. The number of records to show for this page. Min 1, Max 500.
    type: int
  offset:
    description:
      - Offset query parameter.
    type: int
  nameList:
    description:
      - NameList query parameter.
    elements: str
    type: list
  vendorEquipmentTypeList:
    description:
      - VendorEquipmentTypeList query parameter.
    elements: str
    type: list
  partNumberList:
    description:
      - PartNumberList query parameter.
    elements: str
    type: list
  operationalStateCodeList:
    description:
      - OperationalStateCodeList query parameter.
    elements: str
    type: list
  id:
    description:
      - Id path parameter. Module id.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices GetModuleInfoById
    description: Complete reference of the GetModuleInfoById API.
    link: https://developer.cisco.com/docs/dna-center/#!get-module-info-by-id
  - name: Cisco DNA Center documentation for Devices GetModules
    description: Complete reference of the GetModules API.
    link: https://developer.cisco.com/docs/dna-center/#!get-modules
notes:
  - SDK Method used are
    devices.Devices.get_module_info_by_id,
    devices.Devices.get_modules,
  - Paths used are
    get /dna/intent/api/v1/network-device/module,
    get /dna/intent/api/v1/network-device/module/{id},
"""

EXAMPLES = r"""
---
- name: Get all Network Device Module
  cisco.dnac.network_device_module_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    deviceId: string
    limit: 0
    offset: 0
    nameList: []
    vendorEquipmentTypeList: []
    partNumberList: []
    operationalStateCodeList: []
  register: result
- name: Get Network Device Module by id
  cisco.dnac.network_device_module_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "assemblyNumber": "string",
        "assemblyRevision": "string",
        "attributeInfo": {},
        "containmentEntity": "string",
        "description": "string",
        "entityPhysicalIndex": "string",
        "id": "string",
        "isFieldReplaceable": "string",
        "isReportingAlarmsAllowed": "string",
        "manufacturer": "string",
        "moduleIndex": 0,
        "name": "string",
        "operationalStateCode": "string",
        "partNumber": "string",
        "serialNumber": "string",
        "vendorEquipmentType": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_rf_profiles_info
short_description: Information module for Wireless Settings Rf Profiles
description:
  - Get all Wireless Settings Rf Profiles.
  - Get Wireless Settings Rf Profiles by id.
  - This API allows the user to get a RF Profile by RF Profile ID.
  - This API allows the user to get all RF Profiles.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  limit:
    description:
      - >
        Limit query parameter. The number of records to show for this page. Default is 500 if not specified.
        Maximum allowed limit is 500.
    type: int
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
  rfProfileName:
    description:
      - RfProfileName query parameter. RF Profile Name.
    type: str
  enableRadioTypeA:
    description:
      - EnableRadioTypeA query parameter. Enable Radio TypeA.
    type: bool
  enableRadioTypeB:
    description:
      - EnableRadioTypeB query parameter. Enable Radio TypeB.
    type: bool
  enableRadioType6GHz:
    description:
      - EnableRadioType6GHz query parameter. Enable Radio Type6GHz.
    type: bool
  id:
    description:
      - Id path parameter. RF Profile ID.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless GetRFProfileByID
    description: Complete reference of the GetRFProfileByID API.
    link: https://developer.cisco.com/docs/dna-center/#!get-rf-profile-by-id
  - name: Cisco DNA Center documentation for Wireless GetRFProfiles
    description: Complete reference of the GetRFProfiles API.
    link: https://developer.cisco.com/docs/dna-center/#!get-rf-profiles
notes:
  - SDK Method used are
    wireless.Wireless.get_rf_profile_by_id,
    wireless.Wireless.get_rf_profiles,
  - Paths used are
    get /dna/intent/api/v1/wirelessSettings/rfProfiles,
    get /dna/intent/api/v1/wirelessSettings/rfProfiles/{id},
"""

EXAMPLES = r"""
---
- name: Get all Wireless Settings Rf Profiles
  cisco.dnac.wireless_settings_rf_profiles_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    limit: 0
    offset: 0
    rfProfileName: string
    enableRadioTypeA: true
    enableRadioTypeB: true
    enableRadioType6GHz: true
  register: result
- name: Get Wireless Settings Rf Profiles by id
  cisco.dnac.wireless_settings_rf_profiles_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "rfProfileName": "string",
          "defaultRfProfile": true,
          "enableRadioTypeA": true,
          "enableRadioTypeB": true,
          "enableRadioType6GHz": true,
          "enableCustom": true,
          "radioTypeAProperties": {
            "parentProfile": "string",
            "radioChannels": "string",
            "dataRates": "string",
            "mandatoryDataRates": "string",
            "powerThresholdV1": 0,
            "rxSopThreshold": "string",
            "minPowerLevel": 0,
            "maxPowerLevel": 0,
            "channelWidth": "string",
            "preamblePuncture": true,
            "zeroWaitDfsEnable": true,
            "customRxSopThreshold": 0,
            "maxRadioClients": 0,
            "fraPropertiesA": {
              "clientAware": true,
              "clientSelect": 0,
              "clientReset": 0
            },
            "coverageHoleDetectionProperties": {
              "chdClientLevel": 0,
              "chdDataRssiThreshold": 0,
              "chdVoiceRssiThreshold": 0,
              "chdExceptionLevel": 0
            },
            "spatialReuseProperties": {
              "dot11axNonSrgObssPacketDetect": true,
              "dot11axNonSrgObssPacketDetectMaxThreshold": 0,
              "dot11axSrgObssPacketDetect": true,
              "dot11axSrgObssPacketDetectMinThreshold": 0,
              "dot11axSrgObssPacketDetectMaxThreshold": 0
            }
          },
          "radioTypeBProperties": {
            "parentProfile": "string",
            "radioChannels": "string",
            "dataRates": "string",
            "mandatoryDataRates": "string",
            "powerThresholdV1": 0,
            "rxSopThreshold": "string",
            "minPowerLevel": 0,
            "maxPowerLevel": 0,
            "customRxSopThreshold": 0,
            "maxRadioClients": 0,
            "coverageHoleDetectionProperties": {
              "chdClientLevel": 0,
              "chdDataRssiThreshold": 0,
              "chdVoiceRssiThreshold": 0,
              "chdExceptionLevel": 0
            },
            "spatialReuseProperties": {
              "dot11axNonSrgObssPacketDetect": true,
              "dot11axNonSrgObssPacketDetectMaxThreshold": 0,
              "dot11axSrgObssPacketDetect": true,
              "dot11axSrgObssPacketDetectMinThreshold": 0,
              "dot11axSrgObssPacketDetectMaxThreshold": 0
            }
          },
          "radioType6GHzProperties": {
            "parentProfile": "string",
            "radioChannels": "string",
            "dataRates": "string",
            "mandatoryDataRates": "string",
            "powerThresholdV1": 0,
            "rxSopThreshold": "string",
            "minPowerLevel": 0,
            "maxPowerLevel": 0,
            "enableStandardPowerService": true,
            "multiBssidProperties": {
              "dot11axParameters": {
                "ofdmaDownLink": true,
                "ofdmaUpLink": true,
                "muMimoUpLink": true,
                "muMimoDownLink": true
              },
              "dot11beParameters": {
                "ofdmaDownLink": true,
                "ofdmaUpLink": true,
                "muMimoUpLink": true,
                "muMimoDownLink": true,
                "ofdmaMultiRu": true
              },
              "targetWakeTime": true,
              "twtBroadcastSupport": true
            },
            "preamblePuncture": true,
            "minDbsWidth": 0,
            "maxDbsWidth": 0,
            "customRxSopThreshold": 0,
            "maxRadioClients": 0,
            "pscEnforcingEnabled": true,
            "discoveryFrames6GHz": "string",
            "broadcastProbeResponseInterval": 0,
            "fraPropertiesC": {
              "clientResetCount": 0,
              "clientUtilizationThreshold": 0
            },
            "coverageHoleDetectionProperties": {
              "chdClientLevel": 0,
              "chdDataRssiThreshold": 0,
              "chdVoiceRssiThreshold": 0,
              "chdExceptionLevel": 0
            },
            "spatialReuseProperties": {
              "dot11axNonSrgObssPacketDetect": true,
              "dot11axNonSrgObssPacketDetectMaxThreshold": 0,
              "dot11axSrgObssPacketDetect": true,
              "dot11axSrgObssPacketDetectMinThreshold": 0,
              "dot11axSrgObssPacketDetectMaxThreshold": 0
            }
          },
          "id": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: site_health_summaries_summary_analytics
short_description: Resource module for Site Health Summaries Summary Analytics
description:
  - Manage operation create of the resource Site Health Summaries Summary Analytics.
  - Query an aggregated summary of all site health.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  attributes:
    description: Attributes.
    elements: str
    type: list
  endTime:
    description: End Time.
    type: int
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id query parameter. The list of entity Uuids.
      - Example "6bef213c-19ca-4170-8375-b694e251101c".
      - Multiple entity uuids can be provided with '&' separator.
    type: str
  siteHierarchy:
    description:
      - SiteHierarchy query parameter. The full hierarchical breakdown of the site tree.
      - Starting from Global site name and ending with the specific site name.
      - The Root site is named "Global" (Ex. `Global/AreaName/BuildingName/FloorName`).
      - This field supports wildcard asterisk (`*`) character search support.
    type: str
  siteHierarchyId:
    description: SiteHierarchyId query parameter. The full hierarchy breakdown of the site tree in id form starting from Global
      site UUID and ending with the specific site UUID. (Ex. `globalUuid/areaUuid/buildingUuid/floorUuid`) This field supports
      wildcard asterisk (`*`) character search support. E.g. `*uuid*, *uuid, uuid*` Examples `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid
      `(single siteHierarchyId requested) `?siteHierarchyId=globalUuid/areaUuid/buildingUuid/floorUuid&siteHierarchyId=globa...
      (multiple siteHierarchyIds requested).
    type: str
  siteType:
    description: SiteType query parameter. The type of the site. A site can be an area, building, or floor. Default when not
      provided will be `floor,building,area` Examples `?siteType=area` (single siteType requested) `?siteType=area&siteType=building&siteType=floor`
      (multiple siteTypes requested).
    type: str
  startTime:
    description: Start Time.
    type: int
  views:
    description: Views.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Sites QueryAnAggregatedSummaryOfSiteHealthData
    description: Complete reference of the QueryAnAggregatedSummaryOfSiteHealthData API.
    link: https://developer.cisco.com/docs/dna-center/#!query-an-aggregated-summary-of-site-health-data
notes:
  - SDK Method used are
    sites.Sites.query_an_aggregated_summary_of_site_health_data,
  - Paths used are
    post /dna/data/api/v1/siteHealthSummaries/summaryAnalytics,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.site_health_summaries_summary_analytics:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    attributes:
      - string
    endTime: 0
    headers: '{{my_headers | from_json}}'
    id: string
    siteHierarchy: string
    siteHierarchyId: string
    siteType: string
    startTime: 0
    views:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "siteHierarchy": "string",
        "siteHierarchyId": "string",
        "siteType": "string",
        "latitude": 0,
        "longitude": 0,
        "networkDeviceGoodHealthPercentage": 0,
        "networkDeviceGoodHealthCount": 0,
        "clientGoodHealthCount": 0,
        "clientGoodHealthPercentage": 0,
        "wiredClientGoodHealthPercentage": 0,
        "wirelessClientGoodHealthPercentage": 0,
        "clientCount": 0,
        "wiredClientCount": 0,
        "wirelessClientCount": 0,
        "wiredClientGoodHealthCount": 0,
        "wirelessClientGoodHealthCount": 0,
        "networkDeviceCount": 0,
        "accessDeviceCount": 0,
        "accessDeviceGoodHealthCount": 0,
        "coreDeviceCount": 0,
        "coreDeviceGoodHealthCount": 0,
        "distributionDeviceCount": 0,
        "distributionDeviceGoodHealthCount": 0,
        "routerDeviceCount": 0,
        "routerDeviceGoodHealthCount": 0,
        "wirelessDeviceCount": 0,
        "wirelessDeviceGoodHealthCount": 0,
        "apDeviceCount": 0,
        "apDeviceGoodHealthCount": 0,
        "wlcDeviceCount": 0,
        "wlcDeviceGoodHealthCount": 0,
        "switchDeviceCount": 0,
        "switchDeviceGoodHealthCount": 0,
        "accessDeviceGoodHealthPercentage": 0,
        "coreDeviceGoodHealthPercentage": 0,
        "distributionDeviceGoodHealthPercentage": 0,
        "routerDeviceGoodHealthPercentage": 0,
        "apDeviceGoodHealthPercentage": 0,
        "wlcDeviceGoodHealthPercentage": 0,
        "switchDeviceGoodHealthPercentage": 0,
        "wirelessDeviceGoodHealthPercentage": 0,
        "clientDataUsage": 0,
        "p1IssueCount": 0,
        "p2IssueCount": 0,
        "p3IssueCount": 0,
        "p4IssueCount": 0,
        "issueCount": 0
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# GNU General Public License v3.0+ (see COPYING or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function
__metaclass__ = type

ANSIBLE_METADATA = {'metadata_version': '1.1',
                    'status': ['preview'],
                    'supported_by': 'community'}

DOCUMENTATION = r'''
---
module: intersight_resource_group
short_description: Resource Group configuration for Cisco Intersight
description:
  - Manages Resource Group configuration on Cisco Intersight.
  - Resource Groups define a set of resources that can be used for access control and organization assignment.
  - Supports both C(all) and C(selectors) qualifier types.
  - Resource Groups are account-level resources and are not scoped to an organization.
  - For more information see L(Cisco Intersight,https://intersight.com/apidocs/resource/Group/model/).
extends_documentation_fragment: intersight
options:
  state:
    description:
      - If C(present), will verify the resource is present and will create if needed.
      - If C(absent), will verify the resource is absent and will delete if needed.
    type: str
    choices: [present, absent]
    default: present
  name:
    description:
      - The name assigned to the Resource Group.
      - The name must be between 1 and 62 alphanumeric characters, allowing special characters :-_.
    type: str
    required: true
  description:
    description:
      - The user-defined description for the Resource Group.
    type: str
    aliases: [descr]
  tags:
    description:
      - List of tags in Key:<user-defined key> Value:<user-defined value> format.
    type: list
    elements: dict
  qualifier:
    description:
      - Qualifier defines how resources are added to the Resource Group.
      - C(all) includes all resources (represents Allow-All in the API).
      - C(selectors) uses selector queries to filter specific resources (represents Allow-Selectors in the API).
    type: str
    choices: [all, selectors]
    default: all
  selectors:
    description:
      - List of selector query strings used to filter resources for the Resource Group.
      - Required when O(qualifier) is C(selectors).
      - "Each selector is an API path with a filter query."
      - "Example: C(/api/v1/asset/DeviceRegistrations?$filter=Moid in ('moid_value'))"
      - "Example: C(/api/v1/compute/Blades?$filter=Serial in ('serial_value') and ManagementMode eq 'Intersight')"
    type: list
    elements: str
author:
  - Ron Gershburg (@rgershbu)
'''

EXAMPLES = r'''
- name: Create Resource Group with all qualifier
  cisco.intersight.intersight_resource_group:
    api_private_key: "{{ api_private_key }}"
    api_key_id: "{{ api_key_id }}"
    name: "all-resources-group"
    description: "Resource group that includes all resources"
    qualifier: "all"
    state: present

- name: Create Resource Group with selectors for specific devices
  cisco.intersight.intersight_resource_group:
    api_private_key: "{{ api_private_key }}"
    api_key_id: "{{ api_key_id }}"
    name: "selected-devices-group"
    description: "Resource group for specific devices"
    qualifier: "selectors"
    selectors:
      - "/api/v1/asset/DeviceRegistrations?$filter=Moid in ('507f1f77bcf86cd799439011')"
    state: present

- name: Create multiple Resource Groups for UCS domains
  cisco.intersight.intersight_resource_group:
    api_private_key: "{{ api_private_key }}"
    api_key_id: "{{ api_key_id }}"
    name: "{{ item.name }}"
    description: "{{ item.description }}"
    qualifier: "selectors"
    selectors:
      - "{{ item.selector }}"
    state: present
  loop:
    - name: "ucs-lab-domain-1"
      description: "Lab UCS domain 1"
      selector: "/api/v1/asset/DeviceRegistrations?$filter=Moid in ('507f1f77bcf86cd799439011')"
    - name: "ucs-lab-domain-2"
      description: "Lab UCS domain 2"
      selector: "/api/v1/asset/DeviceRegistrations?$filter=Moid in ('507f1f77bcf86cd799439022')"
    - name: "ucs-lab-domain-3"
      description: "Lab UCS domain 3"
      selector: "/api/v1/asset/DeviceRegistrations?$filter=Moid in ('507f1f77bcf86cd799439033')"

- name: Create Resource Group with selectors for compute blades
  cisco.intersight.intersight_resource_group:
    api_private_key: "{{ api_private_key }}"
    api_key_id: "{{ api_key_id }}"
    name: "blade-servers-group"
    qualifier: "selectors"
    selectors:
      - "/api/v1/compute/Blades?$filter=Serial in ('FCH26387CE1') and ManagementMode eq 'Intersight'"
    state: present

- name: Update Resource Group from all to selectors
  cisco.intersight.intersight_resource_group:
    api_private_key: "{{ api_private_key }}"
    api_key_id: "{{ api_key_id }}"
    name: "all-resources-group"
    description: "Now scoped to specific devices"
    qualifier: "selectors"
    selectors:
      - "/api/v1/asset/DeviceRegistrations?$filter=Moid in ('507f1f77bcf86cd799439011')"
    state: present

- name: Delete Resource Group
  cisco.intersight.intersight_resource_group:
    api_private_key: "{{ api_private_key }}"
    api_key_id: "{{ api_key_id }}"
    name: "all-resources-group"
    state: absent
'''

RETURN = r'''
api_response:
  description: The API response output returned by the specified resource.
  returned: always
  type: dict
  sample:
    "api_response": {
        "Name": "all-resources-group",
        "ObjectType": "resource.Group",
        "Description": "Resource group that includes all resources",
        "Qualifier": "Allow-All",
        "Selectors": []
    }
'''

from ansible.module_utils.basic import AnsibleModule
from ansible_collections.cisco.intersight.plugins.module_utils.intersight import IntersightModule, intersight_argument_spec

QUALIFIER_MAP = {
    'all': 'Allow-All',
    'selectors': 'Allow-Selectors',
}


def build_api_body(intersight):
    """Build the API body for Resource Group configuration."""
    params = intersight.module.params
    if params['state'] == 'present':
        intersight.api_body = {
            'Name': params['name'],
            'Qualifier': QUALIFIER_MAP[params['qualifier']],
        }

        if params['qualifier'] == 'selectors' and params.get('selectors'):
            intersight.api_body['Selectors'] = [
                {'Selector': s} for s in params['selectors']
            ]

        intersight.set_tags_and_description()


def main():
    argument_spec = intersight_argument_spec.copy()
    argument_spec.update(
        state=dict(type='str', choices=['present', 'absent'], default='present'),
        name=dict(type='str', required=True),
        description=dict(type='str', aliases=['descr']),
        tags=dict(type='list', elements='dict'),
        qualifier=dict(type='str', choices=['all', 'selectors'], default='all'),
        selectors=dict(type='list', elements='str'),
    )

    module = AnsibleModule(
        argument_spec,
        supports_check_mode=True,
        required_if=[
            ['qualifier', 'selectors', ['selectors']],
        ],
    )

    intersight = IntersightModule(module)
    intersight.result['api_response'] = {}
    intersight.result['trace_id'] = ''

    build_api_body(intersight)

    resource_path = '/resource/Groups'

    intersight.configure_secondary_resource(
        resource_path=resource_path,
        resource_name=module.params['name'],
        state=module.params['state'],
    )

    module.exit_json(**intersight.result)


if __name__ == '__main__':
    main()



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_settings_certificate_renewal_profiles_info
short_description: Information module for Wireless Settings Certificate Renewal Profiles
description:
  - Get all Wireless Settings Certificate Renewal Profiles.
  - Get Wireless Settings Certificate Renewal Profiles by id.
  - GET LSC Certificate Renewal Profile by ID. - > Retrieves the access point certificate renewal profiles that are created
    in the catalyst centre network design for wireless. Filtering can be done on access point certificate renewal profile
    name and renewal type.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  lscProfileName:
    description:
      - >
        LscProfileName query parameter. Access point certificate renewal profile name. Use this query parameter
        to obtain the details of access point certificate renewal profile by its name.
    type: str
  renewalType:
    description:
      - >
        RenewalType query parameter. Access point certificate renewal profile renewal type. Use this query
        parameter to obtain the details of access point certificate renewal profile by its renewal type name.
        Example STAGGERED, ONESHOT.
    type: str
  limit:
    description:
      - Limit query parameter. Pagination limit.
    type: int
  offset:
    description:
      - Offset query parameter. Pagination offset.
    type: int
  id:
    description:
      - Id path parameter. LSC Certificate Renewal Profile ID.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless GETLSCCertificateRenewalProfileByID
    description: Complete reference of the GETLSCCertificateRenewalProfileByID API.
    link: https://developer.cisco.com/docs/dna-center/#!g-etlsc-certificate-renewal-profile-by-id
  - name: Cisco DNA Center documentation for Wireless GetLSCCertificateRenewalProfiles
    description: Complete reference of the GetLSCCertificateRenewalProfiles API.
    link: https://developer.cisco.com/docs/dna-center/#!get-lsc-certificate-renewal-profiles
notes:
  - SDK Method used are
    wireless.Wireless.get_l_s_c_certificate_renewal_profile_by_id,
    wireless.Wireless.get_l_s_c_certificate_renewal_profiles,
  - Paths used are
    get /dna/intent/api/v1/wirelessSettings/certificateRenewalProfiles,
    get /dna/intent/api/v1/wirelessSettings/certificateRenewalProfiles/{id},
"""

EXAMPLES = r"""
---
- name: Get all Wireless Settings Certificate Renewal Profiles
  cisco.dnac.wireless_settings_certificate_renewal_profiles_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    lscProfileName: string
    renewalType: string
    limit: 0
    offset: 0
  register: result
- name: Get Wireless Settings Certificate Renewal Profiles by id
  cisco.dnac.wireless_settings_certificate_renewal_profiles_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "lscProfileName": "string",
      "renewalType": "string",
      "renewalDueInDays": 0,
      "CalendarProfileSetting": {
        "schedulerType": "string",
        "duration": {
          "schedulerDay": [
            "string"
          ],
          "schedulerStartTime": "string",
          "schedulerEndTime": "string",
          "schedulerDate": "string"
        }
      }
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: iot_fabric_rep_rings_delete
short_description: Resource module for Iot Fabric Rep Rings Delete
description:
  - Manage operation delete of the resource Iot Fabric Rep Rings Delete. - > This API deletes the REP ring configured in the
    FABRIC deployment for the given id. The id of configured REP ring can be retrieved using the API /dna/intent/api/v1/iot/repRings/query.The
    taskid returned can be used to monitor the status of delete operation using following API -/intent/api/v1/task/{taskId}.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Ring ID of configured REP ring can be fetched using the API `/dna/intent/api/v1/iot/repRings/query`.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Industrial Configuration DeleteREPRingConfiguredInTheFABRICDeployment
    description: Complete reference of the DeleteREPRingConfiguredInTheFABRICDeployment API.
    link: https://developer.cisco.com/docs/dna-center/#!delete-rep-ring-configured-in-the-fabric-deployment
notes:
  - SDK Method used are
    industrial_configuration.IndustrialConfiguration.delete_r_e_p_ring_configured_in_the_f_a_b_r_i_c_deployment,
  - Paths used are
    delete /dna/intent/api/v1/iot/fabric/repRings/{id},
"""

EXAMPLES = r"""
---
- name: Delete by id
  cisco.dnac.iot_fabric_rep_rings_delete:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    id: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: wireless_controllers_mesh_ap_neighbours_info
short_description: Information module for Wireless Controllers Mesh Ap Neighbours
description:
  - Get all Wireless Controllers Mesh Ap Neighbours. - > Retrieves all mesh access point neighbour details, including Child,
    Parent, Neighbour, Tentative Parent, and Blocklisted statuses.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  wlcIpAddress:
    description:
      - >
        WlcIpAddress query parameter. Employ this query parameter to obtain the details of the access points
        corresponding to the provided WLC IP address.
    type: str
  apName:
    description:
      - >
        ApName query parameter. Employ this query parameter to obtain the details of the access points
        corresponding to the provided access point name.
    type: str
  ethernetMacAddress:
    description:
      - >
        EthernetMacAddress query parameter. Employ this query parameter to obtain the details of the access
        points corresponding to the provided ethernet MAC address.
    type: str
  meshRole:
    description:
      - >
        MeshRole query parameter. Employ this query parameter to obtain the details of the access points
        corresponding to the provided mesh role. Allowed values are RAP or MAP.
    type: str
  neighbourType:
    description:
      - >
        NeighbourType query parameter. Employ this query parameter to obtain the details of the access points
        corresponding to the provided mesh neighbour type. Allowed values are Child, Parent, Neigh, Tentative
        Parent, Blocklisted.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Wireless GetMeshApNeighbours
    description: Complete reference of the GetMeshApNeighbours API.
    link: https://developer.cisco.com/docs/dna-center/#!get-mesh-ap-neighbours
notes:
  - SDK Method used are
    wireless.Wireless.get_mesh_ap_neighbours,
  - Paths used are
    get /dna/intent/api/v1/wirelessControllers/meshApNeighbours,
"""

EXAMPLES = r"""
---
- name: Get all Wireless Controllers Mesh Ap Neighbours
  cisco.dnac.wireless_controllers_mesh_ap_neighbours_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    wlcIpAddress: string
    apName: string
    ethernetMacAddress: string
    meshRole: string
    neighbourType: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "id": "string",
      "apName": "string",
      "ethernetMacAddress": "string",
      "neighbourMacAddress": "string",
      "wlcIpAddress": "string",
      "neighbourType": "string",
      "meshRole": "string",
      "neighbourApName": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: install_optional_packages_create
short_description: Resource module for Install Optional Packages Create
description:
  - Manage operation create of the resource Install Optional Packages Create.
  - This API is used to trigger the workflow for installing optional packages.
version_added: '6.46.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  optionalPackages:
    description: Provide the list of optional package's id to be installed .Use the /dna/system/api/v1/releases/releaseSummary
      API to obtain the optional package IDs. The `releaseName` and `releaseVersion` should correspond to the installed release
      name and version, which can be obtained from the `name` and `version` attributes in the response of the `/dna/system/api/v1/installedRelease`
      API. In the releaseSummary API response, optional packages can be identified by the attribute `packagesn.optional` is
      true. Provide the `packagesn.id` of these optional packages.
    elements: str
    type: list
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for System Software Upgrade InstallOptionalPackages
    description: Complete reference of the InstallOptionalPackages API.
    link: https://developer.cisco.com/docs/dna-center/#!install-optional-packages
notes:
  - SDK Method used are
    system_software_upgrade.SystemSoftwareUpgrade.install_optional_packages,
  - Paths used are
    post /dna/system/api/v1/installOptionalPackages,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.install_optional_packages_create:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    optionalPackages:
      - string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: assurance_events_child_events_info
short_description: Information module for Assurance Events Child Events
description:
  - Get all Assurance Events Child Events.
  - Wireless client event could have child events and this API can be used to fetch the same using parent event
    `id` as the input.
  - For detailed information about the usage of the API, please refer to the Open API specification document
    https //github.com/cisco-en-programmability/catalyst-center-api-specs/blob/main/Assurance/CE_Cat_Center_Org-AssuranceEvents-1.0.0-resolved.yaml.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id path parameter. Unique identifier for the event.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Devices GetListOfChildEventsForTheGivenWirelessClientEvent
    description: Complete reference of the GetListOfChildEventsForTheGivenWirelessClientEvent API.
    link: https://developer.cisco.com/docs/dna-center/#!get-list-of-child-events-for-the-given-wireless-client-event
notes:
  - SDK Method used are
    devices.Devices.get_list_of_child_events_for_the_given_wireless_client_event,
  - Paths used are
    get /dna/data/api/v1/assuranceEvents/{id}/childEvents,
"""

EXAMPLES = r"""
---
- name: Get all Assurance Events Child Events
  cisco.dnac.assurance_events_child_events_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": [
        {
          "id": "string",
          "name": "string",
          "timestamp": 0,
          "wirelessEventType": 0,
          "details": "string",
          "reasonCode": "string",
          "subreasonCode": "string",
          "resultStatus": "string",
          "reasonDescription": "string",
          "subReasonDescription": "string",
          "failureCategory": "string"
        }
      ],
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: network_device_config_files_info
short_description: Information module for Network Device Config Files
description:
  - Get all Network Device Config Files.
  - Get Network Device Config Files by id.
  - Retrieves the details of a specific network device configuration file using the `id`. - > Retrieves the list of network
    device configuration file details, sorted by createdTime in descending order. Use /intent/api/v1/networkDeviceConfigFiles/{id}/downloadMasked
    to download masked configurations, or /intent/api/v1/networkDeviceConfigFiles/{id}/downloadUnmasked for unmasked configurations.
version_added: '6.17.0'
extends_documentation_fragment:
  - cisco.dnac.module_info
author: Rafael Campos (@racampos)
options:
  headers:
    description: Additional headers.
    type: dict
  id:
    description:
      - Id query parameter. Unique identifier (UUID) of the configuration file.
    type: str
  networkDeviceId:
    description:
      - >
        NetworkDeviceId query parameter. Unique identifier (UUID) of the network devices. The number of
        networkDeviceId(s) must not exceed 5.
    type: str
  fileType:
    description:
      - >
        FileType query parameter. Type of device configuration file.Available values 'RUNNINGCONFIG',
        'STARTUPCONFIG', 'VLAN'.
    type: str
  offset:
    description:
      - Offset query parameter. The first record to show for this page; the first record is numbered 1.
    type: int
  limit:
    description:
      - >
        Limit query parameter. The number of records to be retrieved defaults to 500 if not specified, with a
        maximum allowed limit of 500.
    type: int
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Configuration Archive GetConfigurationFileDetailsByID
    description: Complete reference of the GetConfigurationFileDetailsByID API.
    link: https://developer.cisco.com/docs/dna-center/#!get-configuration-file-details-by-id
  - name: Cisco DNA Center documentation for Configuration Archive GetNetworkDeviceConfigurationFileDetails
    description: Complete reference of the GetNetworkDeviceConfigurationFileDetails API.
    link: https://developer.cisco.com/docs/dna-center/#!get-network-device-configuration-file-details
notes:
  - SDK Method used are
    configuration_archive.ConfigurationArchive.get_configuration_file_details_by_id,
    configuration_archive.ConfigurationArchive.get_network_device_configuration_file_details,
  - Paths used are
    get /dna/intent/api/v1/networkDeviceConfigFiles,
    get /dna/intent/api/v1/networkDeviceConfigFiles/{id},
"""

EXAMPLES = r"""
---
- name: Get all Network Device Config Files
  cisco.dnac.network_device_config_files_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
    networkDeviceId: string
    fileType: string
    offset: 0
    limit: 0
  register: result
- name: Get Network Device Config Files by id
  cisco.dnac.network_device_config_files_info:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    headers: "{{my_headers | from_json}}"
    id: string
  register: result
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "id": "string",
        "networkDeviceId": "string",
        "versionId": "string",
        "fileType": "string",
        "createdBy": "string",
        "createdTime": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: images_distribution_server_settings
short_description: Resource module for Images Distribution Server Settings
description:
  - Manage operations create, update and delete of the resource Images Distribution Server Settings.
  - Add remote server for distributing software images. Upto two such distribution servers are supported.
  - Delete remote image distribution server.
  - Update remote image distribution server details.
version_added: '6.15.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  id:
    description: Id path parameter. Remote server identifier.
    type: str
  password:
    description: Server password.
    type: str
  portNumber:
    description: Port number.
    type: float
  rootLocation:
    description: Server root location.
    type: str
  serverAddress:
    description: FQDN or IP address of the server.
    type: str
  username:
    description: Server username.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) AddImageDistributionServer
    description: Complete reference of the AddImageDistributionServer API.
    link: https://developer.cisco.com/docs/dna-center/#!add-image-distribution-server
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) RemoveImageDistributionServer
    description: Complete reference of the RemoveImageDistributionServer API.
    link: https://developer.cisco.com/docs/dna-center/#!remove-image-distribution-server
  - name: Cisco DNA Center documentation for Software Image Management (SWIM) UpdateRemoteImageDistributionServer
    description: Complete reference of the UpdateRemoteImageDistributionServer API.
    link: https://developer.cisco.com/docs/dna-center/#!update-remote-image-distribution-server
notes:
  - SDK Method used are
    software_image_management_swim.SoftwareImageManagementSwim.add_image_distribution_server,
    software_image_management_swim.SoftwareImageManagementSwim.remove_image_distribution_server,
    software_image_management_swim.SoftwareImageManagementSwim.update_remote_image_distribution_server,
  - Paths used are
    post /dna/intent/api/v1/images/distributionServerSettings,
    delete /dna/intent/api/v1/images/distributionServerSettings/{id},
    put /dna/intent/api/v1/images/distributionServerSettings/{id},
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.images_distribution_server_settings:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    password: string
    portNumber: 0
    rootLocation: string
    serverAddress: string
    username: string
- name: Delete by id
  cisco.dnac.images_distribution_server_settings:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: absent
    id: string
- name: Update by id
  cisco.dnac.images_distribution_server_settings:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    state: present
    id: string
    password: string
    portNumber: 0
    username: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: dict
  sample: >
    {
      "response": {
        "taskId": "string",
        "url": "string"
      },
      "version": "string"
    }
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright (c) 2021, Cisco Systems
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

DOCUMENTATION = r"""
---
module: iot_rep_rings_query_count
short_description: Resource module for Iot Rep Rings Query Count
description:
  - Manage operation create of the resource Iot Rep Rings Query Count. - > This API returns the count of REP rings for the
    given fields - networkDeviceId Network device ID of the REP ring member. The networkDeviceId is the instanceUuid attribute
    in the response of API - /dna/intent/api/v1/networkDevices and deploymentMode FABRIC/NON_FABRIC .
version_added: '6.18.0'
extends_documentation_fragment:
  - cisco.dnac.module
author: Rafael Campos (@racampos)
options:
  deploymentMode:
    description: Deployment mode of the configured REP ring.
    type: str
  networkDeviceId:
    description: Network device id of the REP ring member. API `/dna/intent/api/v1/networkDevices` can be used to get the
      list of networkDeviceIds of the neighbors , `instanceUuid` attribute in the response contains networkDeviceId.
    type: str
requirements:
  - dnacentersdk >= 2.11.0
  - python >= 3.12
seealso:
  - name: Cisco DNA Center documentation for Industrial Configuration RetrievesTheCountOfREPRings
    description: Complete reference of the RetrievesTheCountOfREPRings API.
    link: https://developer.cisco.com/docs/dna-center/#!retrieves-the-count-of-rep-rings
notes:
  - SDK Method used are
    industrial_configuration.IndustrialConfiguration.retrieves_the_count_of_r_e_p_rings,
  - Paths used are
    post /dna/intent/api/v1/iot/repRings/query/count,
"""

EXAMPLES = r"""
---
- name: Create
  cisco.dnac.iot_rep_rings_query_count:
    dnac_host: "{{dnac_host}}"
    dnac_username: "{{dnac_username}}"
    dnac_password: "{{dnac_password}}"
    dnac_verify: "{{dnac_verify}}"
    dnac_port: "{{dnac_port}}"
    dnac_version: "{{dnac_version}}"
    dnac_debug: "{{dnac_debug}}"
    deploymentMode: string
    networkDeviceId: string
"""
RETURN = r"""
dnac_response:
  description: A dictionary or list with the response returned by the Cisco DNAC Python SDK
  returned: always
  type: list
  sample: >
    [
      {
        "response": [
          {
            "count": 0
          }
        ],
        "version": 0
      }
    ]
"""



#!/usr/bin/python
# -*- coding: utf-8 -*-

# Copyright: (c) 2023, Samita Bhattacharjee (@samitab) <samitab@cisco.com>
# GNU General Public License v3.0+ (see LICENSE or https://www.gnu.org/licenses/gpl-3.0.txt)

from __future__ import absolute_import, division, print_function

__metaclass__ = type

ANSIBLE_METADATA = {"metadata_version": "1.1", "status": ["preview"], "supported_by": "certified"}

DOCUMENTATION = r"""
---
module: aci_fabric_pod_external_tep
short_description: Manage Fabric Pod External TEP (fabric:ExtRoutablePodSubnet)
description:
- Manage Fabric Pod External TEP Subnets.
options:
  pod_id:
    description:
    - The Pod ID for the External TEP.
    type: int
    aliases: [ pod ]
  description:
    description:
    - The description for the External TEP.
    type: str
    aliases: [ descr ]
  name_alias:
    description:
    - The alias for the current object. This relates to the nameAlias field in ACI.
    type: str
  external_tep_pool:
    description:
    - The subnet IP address pool for the External TEP.
    - Must be valid IPv4 and include the subnet mask.
    - Example 192.168.1.0/24
    type: str
    aliases: [ ip, ip_address, tep_pool, pool ]
  reserve_address_count:
    description:
    - Indicates the number of IP addresses that are reserved from the start of the subnet.
    type: int
    aliases: [ address_count ]
  status:
    description:
    - State of the External TEP C(active) or C(inactive).
    - An External TEP can only be deleted when the state is inactive.
    - The APIC defaults to C(active) when unset during creation.
    type: str
    choices: [ active, inactive ]
  state:
    description:
    - Use C(present) or C(absent) for adding or removing.
    - Use C(query) for listing an object or multiple objects.
    type: str
    choices: [ absent, present, query ]
    default: present
extends_documentation_fragment:
- cisco.aci.aci
- cisco.aci.annotation
- cisco.aci.owner

notes:
- The C(Fabric Pod Setup Policy) must exist before using this module in your playbook.
  The M(cisco.aci.aci_fabric_pod) module can be used for this.
seealso:
- name: APIC Management Information Model reference
  description: More information about the internal APIC class B(fabric:ExtRoutablePodSubnet).
  link: https://developer.cisco.com/docs/apic-mim-ref/
author:
- Samita Bhattacharjee (@samitab)
"""

EXAMPLES = r"""
- name: Add an External TEP to a fabric pod setup policy
  cisco.aci.aci_fabric_pod_external_tep:
    host: apic
    username: admin
    password: SomeSecretPassword
    pod_id: 2
    external_tep_pool: 10.6.1.0/24
    reserve_address_count: 5
    status: active
    state: present
  delegate_to: localhost

- name: Change an External TEP state on a fabric pod setup policy to inactive
  cisco.aci.aci_fabric_pod_external_tep:
    host: apic
    username: admin
    password: SomeSecretPassword
    pod_id: 2
    external_tep_pool: 10.6.1.0/24
    status: inactive
    state: present
  delegate_to: localhost

- name: Query the External TEP on a fabric pod setup policy
  cisco.aci.aci_fabric_pod_external_tep:
    host: apic
    username: admin
    password: SomeSecretPassword
    pod_id: 2
    external_tep_pool: 10.6.1.0/24
    state: query
  delegate_to: localhost
  register: query_result

- name: Query External TEPs on all fabric pod setup policies
  cisco.aci.aci_fabric_pod_external_tep:
    host: apic
    username: admin
    password: SomeSecretPassword
    state: query
  delegate_to: localhost
  register: query_result

- name: Delete an External TEP on a fabric pod setup policy
  cisco.aci.aci_fabric_pod_external_tep:
    host: apic
    username: admin
    password: SomeSecretPassword
    pod_id: 2
    external_tep_pool: 10.6.1.0/24
    state: absent
  delegate_to: localhost
"""

RETURN = r"""
current:
  description: The existing configuration from the APIC after the module has finished
  returned: success
  type: list
  sample:
    [
        {
            "fvTenant": {
                "attributes": {
                    "descr": "Production environment",
                    "dn": "uni/tn-production",
                    "name": "production",
                    "nameAlias": "",
                    "ownerKey": "",
                    "ownerTag": ""
                }
            }
        }
    ]
error:
  description: The error information as returned from the APIC
  returned: failure
  type: dict
  sample:
    {
        "code": "122",
        "text": "unknown managed object class foo"
    }
raw:
  description: The raw output returned by the APIC REST API (xml or json)
  returned: parse error
  type: str
  sample: '<?xml version="1.0" encoding="UTF-8"?><imdata totalCount="1"><error code="122" text="unknown managed object class foo"/></imdata>'
sent:
  description: The actual/minimal configuration pushed to the APIC
  returned: info
  type: list
  sample:
    {
        "fvTenant": {
            "attributes": {
                "descr": "Production environment"
            }
        }
    }
previous:
  description: The original configuration from the APIC before the module has started
  returned: info
  type: list
  sample:
    [
        {
            "fvTenant": {
                "attributes": {
                    "descr": "Production",
                    "dn": "uni/tn-production",
                    "name": "production",
                    "nameAlias": "",
                    "ownerKey": "",
                    "ownerTag": ""
                }
            }
        }
    ]
proposed:
  description: The assembled configuration from the user-provided parameters
  returned: info
  type: dict
  sample:
    {
        "fvTenant": {
            "attributes": {
                "descr": "Production environment",
                "name": "production"
            }
        }
    }
filter_string:
  description: The filter string used for the request
  returned: failure or debug
  type: str
  sample: ?rsp-prop-include=config-only
method:
  description: The HTTP method used for the request to the APIC
  returned: failure or debug
  type: str
  sample: POST
response:
  description: The HTTP response from the APIC
  returned: failure or debug
  type: str
  sample: OK (30 bytes)
status:
  description: The HTTP status from the APIC
  returned: failure or debug
  type: int
  sample: 200
url:
  description: The HTTP url used for the request to the APIC
  returned: failure or debug
  type: str
  sample: https://10.11.12.13/api/mo/uni/tn-production.json
"""

from ansible.module_utils.basic import AnsibleModule
from ansible_collections.cisco.aci.plugins.module_utils.aci import (
    ACIModule,
    aci_argument_spec,
    aci_annotation_spec,
    aci_owner_spec,
)


def main():
    argument_spec = aci_argument_spec()
    argument_spec.update(aci_annotation_spec())
    argument_spec.update(aci_owner_spec())
    argument_spec.update(
        description=dict(type="str", aliases=["descr"]),
        name_alias=dict(type="str"),
        pod_id=dict(type="int", aliases=["pod"]),
        external_tep_pool=dict(type="str", aliases=["ip", "ip_address", "tep_pool", "pool"]),
        reserve_address_count=dict(type="int", aliases=["address_count"]),
        status=dict(type="str", choices=["active", "inactive"]),
        state=dict(type="str", default="present", choices=["absent", "present", "query"]),
    )

    module = AnsibleModule(
        argument_spec=argument_spec,
        supports_check_mode=True,
        required_if=[
            ["state", "absent", ["pod_id", "external_tep_pool"]],
            ["state", "present", ["pod_id", "external_tep_pool"]],
        ],
    )

    aci = ACIModule(module)

    pod_id = module.params.get("pod_id")
    descr = module.params.get("descr")
    name_alias = module.params.get("name_alias")
    external_tep_pool = module.params.get("external_tep_pool")
    reserve_address_count = module.params.get("reserve_address_count")
    status = module.params.get("status")
    state = module.params.get("state")

    if pod_id is not None and int(pod_id) not in range(1, 254):
        aci.fail_json(msg="Pod ID: {0} is invalid; it must be in the range of 1 to 254.".format(pod_id))

    aci.construct_url(
        root_class=dict(
            aci_class="fabricSetupP",
            aci_rn="controller/setuppol/setupp-{0}".format(pod_id),
            module_object=pod_id,
            target_filter={"podId": pod_id},
        ),
        subclass_1=dict(
            aci_class="fabricExtRoutablePodSubnet",
            aci_rn="extrtpodsubnet-[{0}]".format(external_tep_pool),
            module_object=external_tep_pool,
            target_filter={"pool": external_tep_pool},
        ),
    )

    aci.get_existing()

    if state == "present":
        aci.payload(
            aci_class="fabricExtRoutablePodSubnet",
            class_config=dict(
                descr=descr,
                nameAlias=name_alias,
                pool=external_tep_pool,
                reserveAddressCount=reserve_address_count,
                state=status,
            ),
        )

        aci.get_diff(aci_class="fabricExtRoutablePodSubnet")

        aci.post_config()

    elif state == "absent":
        aci.delete_config()

    aci.exit_json()


if __name__ == "__main__":
    main()
